@@ -2,6 +2,6 @@ var _ogre_data_stream_8h =
 [
     [ "Ogre::StaticCache< cacheSize >", "class_ogre_1_1_static_cache.html", "class_ogre_1_1_static_cache" ],
     [ "OGRE_STREAM_TEMP_SIZE", "_ogre_data_stream_8h.html#a71a2d398037a64aa241ef5c0be350430", null ],
-    [ "DataStreamList", "_ogre_data_stream_8h.html#ga0c97d13889976a6aa046339864f3cdf9", null ],
-    [ "DataStreamListPtr", "_ogre_data_stream_8h.html#gaca357d60ac34de84a39467c1f557749e", null ]
+    [ "Ogre::DataStreamList", "group___resources.html#ga0c97d13889976a6aa046339864f3cdf9", null ],
+    [ "Ogre::DataStreamListPtr", "group___resources.html#gaca357d60ac34de84a39467c1f557749e", null ]
 ];
\ No newline at end of file
