@@ -2,8 +2,6 @@ var _ogre_g_l3_plus_default_hardware_buffer_manager_8h =
 [
     [ "Ogre::v1::GL3PlusDefaultHardwareBufferManager", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager" ],
     [ "Ogre::v1::GL3PlusDefaultHardwareBufferManagerBase", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base" ],
-    [ "Ogre::v1::GL3PlusDefaultHardwareCounterBuffer", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer" ],
     [ "Ogre::v1::GL3PlusDefaultHardwareIndexBuffer", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_index_buffer.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_index_buffer" ],
-    [ "Ogre::v1::GL3PlusDefaultHardwareUniformBuffer", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_uniform_buffer.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_uniform_buffer" ],
     [ "Ogre::v1::GL3PlusDefaultHardwareVertexBuffer", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_vertex_buffer.html", "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_vertex_buffer" ]
 ];
\ No newline at end of file
