@@ -1,9 +1,8 @@
 var _ogre_id_string_8h =
 [
     [ "Ogre::IdString", "struct_ogre_1_1_id_string.html", "struct_ogre_1_1_id_string" ],
-    [ "OGRE_APPEND_DEBUG_STRING", "_ogre_id_string_8h.html#ae3f94271f7f89f67005a57e171e59ebb", null ],
-    [ "OGRE_COPY_DEBUG_STRING", "_ogre_id_string_8h.html#a1e70fee37aed5310cd150b404d282b84", null ],
+    [ "OGRE_DEBUG_STR_SIZE", "_ogre_id_string_8h.html#a76df4aa2317392de6730341e372598ea", null ],
     [ "OGRE_HASH_BITS", "_ogre_id_string_8h.html#a65d81f8d195ea976dbed9daee4cc31f0", null ],
     [ "OGRE_HASH_FUNC", "_ogre_id_string_8h.html#a295b313eb759fefc52c8e195bb9c8e01", null ],
-    [ "IdStringVec", "_ogre_id_string_8h.html#af5d7e0eaf474c82bfa2bf21d0c624d20", null ]
+    [ "Ogre::IdStringVec", "namespace_ogre.html#af5d7e0eaf474c82bfa2bf21d0c624d20", null ]
 ];
\ No newline at end of file
