@@ -4,5 +4,5 @@ var _ogre_lod_config_8h =
     [ "Ogre::LodConfig::Advanced", "struct_ogre_1_1_lod_config_1_1_advanced.html", "struct_ogre_1_1_lod_config_1_1_advanced" ],
     [ "Ogre::LodLevel", "struct_ogre_1_1_lod_level.html", "struct_ogre_1_1_lod_level" ],
     [ "Ogre::ProfiledEdge", "struct_ogre_1_1_profiled_edge.html", "struct_ogre_1_1_profiled_edge" ],
-    [ "LodProfile", "_ogre_lod_config_8h.html#a8f2ca3c32da32a6a5eb07e12bfdcb1aa", null ]
+    [ "Ogre::LodProfile", "namespace_ogre.html#a8f2ca3c32da32a6a5eb07e12bfdcb1aa", null ]
 ];
\ No newline at end of file
