@@ -1,5 +1,5 @@
 var _ogre_resource_background_queue_8h =
 [
     [ "Ogre::ResourceBackgroundQueue::Listener", "class_ogre_1_1_resource_background_queue_1_1_listener.html", "class_ogre_1_1_resource_background_queue_1_1_listener" ],
-    [ "BackgroundProcessTicket", "_ogre_resource_background_queue_8h.html#ga1e2e9ee3e2ee22a4e792952239d38821", null ]
+    [ "Ogre::BackgroundProcessTicket", "group___resources.html#ga1e2e9ee3e2ee22a4e792952239d38821", null ]
 ];
\ No newline at end of file
