@@ -2,6 +2,6 @@ var _ogre_vertex_array_object_8h =
 [
     [ "Ogre::VertexArrayObject", "struct_ogre_1_1_vertex_array_object.html", "struct_ogre_1_1_vertex_array_object" ],
     [ "Ogre::VertexArrayObject::ReadRequests", "struct_ogre_1_1_vertex_array_object_1_1_read_requests.html", "struct_ogre_1_1_vertex_array_object_1_1_read_requests" ],
-    [ "SharedVertexBufferMap", "_ogre_vertex_array_object_8h.html#ad924a6b3cd9a60730cdbe63b37dd6efb", null ],
-    [ "VertexBufferPackedVec", "_ogre_vertex_array_object_8h.html#a0a4ccde77034efa918c66e561958949a", null ]
+    [ "Ogre::SharedVertexBufferMap", "namespace_ogre.html#ad924a6b3cd9a60730cdbe63b37dd6efb", null ],
+    [ "Ogre::VertexBufferPackedVec", "namespace_ogre.html#a0a4ccde77034efa918c66e561958949a", null ]
 ];
\ No newline at end of file
