@@ -2,6 +2,6 @@ var _ogre_vertex_buffer_packed_8h =
 [
     [ "Ogre::VertexBufferPacked", "class_ogre_1_1_vertex_buffer_packed.html", "class_ogre_1_1_vertex_buffer_packed" ],
     [ "Ogre::VertexElement2", "struct_ogre_1_1_vertex_element2.html", "struct_ogre_1_1_vertex_element2" ],
-    [ "VertexElement2Vec", "_ogre_vertex_buffer_packed_8h.html#a03b06afe794fcbba8e2d2172892a80f6", null ],
-    [ "VertexElement2VecVec", "_ogre_vertex_buffer_packed_8h.html#abdf543378d3741e0b20039e582e55a16", null ]
+    [ "Ogre::VertexElement2Vec", "namespace_ogre.html#a03b06afe794fcbba8e2d2172892a80f6", null ],
+    [ "Ogre::VertexElement2VecVec", "namespace_ogre.html#abdf543378d3741e0b20039e582e55a16", null ]
 ];
\ No newline at end of file
