@@ -2,5 +2,5 @@ var _ogre_vertex_index_data_8h =
 [
     [ "Ogre::v1::VertexData::HardwareAnimationData", "struct_ogre_1_1v1_1_1_vertex_data_1_1_hardware_animation_data.html", "struct_ogre_1_1v1_1_1_vertex_data_1_1_hardware_animation_data" ],
     [ "Ogre::v1::VertexData::ReadRequests", "struct_ogre_1_1v1_1_1_vertex_data_1_1_read_requests.html", "struct_ogre_1_1v1_1_1_vertex_data_1_1_read_requests" ],
-    [ "BufferUsageList", "_ogre_vertex_index_data_8h.html#gac447334468fd281ee1a3548172f5d349", null ]
+    [ "Ogre::v1::BufferUsageList", "group___render_system.html#gac447334468fd281ee1a3548172f5d349", null ]
 ];
\ No newline at end of file
