@@ -1,5 +1,5 @@
 var _ogre_volume_cache_source_8h =
 [
     [ "Ogre::Volume::CacheSource", "class_ogre_1_1_volume_1_1_cache_source.html", "class_ogre_1_1_volume_1_1_cache_source" ],
-    [ "operator<", "_ogre_volume_cache_source_8h.html#a8da49f5068936374cdd572df6699b4dd", null ]
+    [ "Ogre::Volume::operator<", "namespace_ogre_1_1_volume.html#a8da49f5068936374cdd572df6699b4dd", null ]
 ];
\ No newline at end of file
