@@ -2,5 +2,5 @@ var _ogre_volume_chunk_handler_8h =
 [
     [ "Ogre::Volume::ChunkHandler", "class_ogre_1_1_volume_1_1_chunk_handler.html", "class_ogre_1_1_volume_1_1_chunk_handler" ],
     [ "Ogre::Volume::ChunkRequest", "struct_ogre_1_1_volume_1_1_chunk_request.html", "struct_ogre_1_1_volume_1_1_chunk_request" ],
-    [ "ChunkRequest", "_ogre_volume_chunk_handler_8h.html#a67c04de7dae4381e03be17c2a498ff58", null ]
+    [ "Ogre::Volume::ChunkRequest", "namespace_ogre_1_1_volume.html#a67c04de7dae4381e03be17c2a498ff58", null ]
 ];
\ No newline at end of file
