@@ -4,6 +4,5 @@ var class_ogre_1_1_create_compositor_script_compiler_event =
     [ "eventType", "class_ogre_1_1_create_compositor_script_compiler_event.html#aef2a0596e638e688e695dafc3d5d1521", null ],
     [ "mFile", "class_ogre_1_1_create_compositor_script_compiler_event.html#a1b8f501137d19fd80f68007ff788fce8", null ],
     [ "mName", "class_ogre_1_1_create_compositor_script_compiler_event.html#a9f07c294aeb33e46ef06d758add7d584", null ],
-    [ "mResourceGroup", "class_ogre_1_1_create_compositor_script_compiler_event.html#ab81debbe356569675c115026c16642eb", null ],
-    [ "mType", "class_ogre_1_1_create_compositor_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6", null ]
+    [ "mResourceGroup", "class_ogre_1_1_create_compositor_script_compiler_event.html#ab81debbe356569675c115026c16642eb", null ]
 ];
\ No newline at end of file
