@@ -4,6 +4,5 @@ var class_ogre_1_1_create_material_script_compiler_event =
     [ "eventType", "class_ogre_1_1_create_material_script_compiler_event.html#a99ee0b5555a50c2786826902f73d7173", null ],
     [ "mFile", "class_ogre_1_1_create_material_script_compiler_event.html#a45a175db818b216a1c2bcec9394557c9", null ],
     [ "mName", "class_ogre_1_1_create_material_script_compiler_event.html#a1d11e1b36c4e3020a17579c2a7dd9cce", null ],
-    [ "mResourceGroup", "class_ogre_1_1_create_material_script_compiler_event.html#af9f939d7217bf645405e2106df7a6612", null ],
-    [ "mType", "class_ogre_1_1_create_material_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6", null ]
+    [ "mResourceGroup", "class_ogre_1_1_create_material_script_compiler_event.html#af9f939d7217bf645405e2106df7a6612", null ]
 ];
\ No newline at end of file
