@@ -5,8 +5,5 @@ var class_ogre_1_1_egl_p_buffer_context =
     [ "clone", "class_ogre_1_1_egl_p_buffer_context.html#a55ff470f470368ebc9e26dfa693f2d91", null ],
     [ "endCurrent", "class_ogre_1_1_egl_p_buffer_context.html#a385571885f435261eeb4fa5092965b5e", null ],
     [ "getDeviceData", "class_ogre_1_1_egl_p_buffer_context.html#a8dcd8f61a534e96e0c1c35cb8b37f337", null ],
-    [ "getInitialized", "class_ogre_1_1_egl_p_buffer_context.html#acc5f8635eda869d7848234b6c35659ca", null ],
-    [ "releaseContext", "class_ogre_1_1_egl_p_buffer_context.html#a1adbc39dc51e3c5dd91795544c2fa352", null ],
-    [ "setCurrent", "class_ogre_1_1_egl_p_buffer_context.html#a27fda5b9f2d30956691788fb643fdb84", null ],
-    [ "setInitialized", "class_ogre_1_1_egl_p_buffer_context.html#a291525177116254970385db2fab2536d", null ]
+    [ "setCurrent", "class_ogre_1_1_egl_p_buffer_context.html#a27fda5b9f2d30956691788fb643fdb84", null ]
 ];
\ No newline at end of file
