@@ -28,25 +28,25 @@ var class_ogre_1_1_scene_manager =
     [ "_addAutotrackingSceneNode", "class_ogre_1_1_scene_manager.html#a9f0b98113bf8c46fc2413f09326b9c9e", null ],
     [ "_addCompositorTexture", "class_ogre_1_1_scene_manager.html#a9203e12ebfaec54ed988e3b0a523ee3c", null ],
     [ "_addWireAabb", "class_ogre_1_1_scene_manager.html#a9a9c54dae09ee2532723cb2d5632be24", null ],
-    [ "_applySceneAnimations", "class_ogre_1_1_scene_manager.html#a58019e4c5104af4fe19d483fb1deec91", null ],
-    [ "_areRenderStateChangesSuppressed", "class_ogre_1_1_scene_manager.html#af7806fd7b6e943c67d80f23de0b3b518", null ],
+    [ "_applySceneAnimations", "class_ogre_1_1_scene_manager.html#aa80de6aa83eaaad929a73061c24bc2fa", null ],
+    [ "_areRenderStateChangesSuppressed", "class_ogre_1_1_scene_manager.html#a561f511a98d8a4537c5343d07ee4352d", null ],
     [ "_calculateCurrentCastersBox", "class_ogre_1_1_scene_manager.html#a245b17763b78ee37c0c281209c43cefd", null ],
     [ "_collectForwardPlusObjects", "class_ogre_1_1_scene_manager.html#a2e915f183603082a83e314967555ac55", null ],
     [ "_createCubemapProbe", "class_ogre_1_1_scene_manager.html#af7bc9d19d31025a52fd76389066ab418", null ],
     [ "_createSceneNode", "class_ogre_1_1_scene_manager.html#a1f068bf536a1b910aa5cd02e55165f35", null ],
     [ "_createTagPoint", "class_ogre_1_1_scene_manager.html#a344584fef03521706592a140a8884b2d", null ],
     [ "_cullPhase01", "class_ogre_1_1_scene_manager.html#ae809ab7de35a8947b1d196006a17720e", null ],
-    [ "_destroyAllCubemapProbes", "class_ogre_1_1_scene_manager.html#a76cbf15335510f68db04b743ac1e25dd", null ],
+    [ "_destroyAllCubemapProbes", "class_ogre_1_1_scene_manager.html#a5f939d39028792c0b38811d734758baf", null ],
     [ "_destroyCubemapProbe", "class_ogre_1_1_scene_manager.html#a1cca7941525cf1c3aa08a6e3dfa5357a", null ],
-    [ "_frameEnded", "class_ogre_1_1_scene_manager.html#ac8061e52306ec97f0a5039e1f0cf79d3", null ],
-    [ "_getActivePassForwardPlus", "class_ogre_1_1_scene_manager.html#afe2b19a98bc975b8810cdb531e912da3", null ],
-    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#a63cec38e600985bbc635b81a260a692c", null ],
-    [ "_getCombinedVisibilityMask", "class_ogre_1_1_scene_manager.html#a981ad410d5a077bb64938685e10fcee0", null ],
+    [ "_frameEnded", "class_ogre_1_1_scene_manager.html#a88574ace95c8fcc5ede8c5e81a7ae83b", null ],
+    [ "_getActivePassForwardPlus", "class_ogre_1_1_scene_manager.html#a5056240756e3528ad95e8caaad7e2765", null ],
+    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#acc0c6f67ccef3d2bf3fae0569b54e500", null ],
+    [ "_getCombinedVisibilityMask", "class_ogre_1_1_scene_manager.html#a280eb49f87f05d662135aadd4221fefc", null ],
     [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae", null ],
     [ "_getEntityMemoryManager", "class_ogre_1_1_scene_manager.html#aabc9effdee88bf684de9409d5d01caab", null ],
-    [ "_getLightMemoryManager", "class_ogre_1_1_scene_manager.html#a8ee3e47c69cf7c122f7d3cc7d8a5329b", null ],
+    [ "_getLightMemoryManager", "class_ogre_1_1_scene_manager.html#a48b9b48d600e83c4463e961a0585cba4", null ],
     [ "_getNodeMemoryManager", "class_ogre_1_1_scene_manager.html#a73f753de4c3a5bf22daf3da16d3b7e27", null ],
-    [ "_getTagPointNodeMemoryManager", "class_ogre_1_1_scene_manager.html#ab4860d8f23e6159b8f09aaf4e18ebcf8", null ],
+    [ "_getTagPointNodeMemoryManager", "class_ogre_1_1_scene_manager.html#af669a83b9010d5cb88c86084a28fd23e", null ],
     [ "_getTmpVisibleObjectsList", "class_ogre_1_1_scene_manager.html#ad195206ee14121a1850dcc3e2f98c15c", null ],
     [ "_handleLodEvents", "class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3", null ],
     [ "_markGpuParamsDirty", "class_ogre_1_1_scene_manager.html#ac631d25ab65e821544835bfa1b507fc2", null ],
@@ -63,10 +63,11 @@ var class_ogre_1_1_scene_manager =
     [ "_renderSingleObject", "class_ogre_1_1_scene_manager.html#ae32663cfb04485c2643a24a1240240c2", null ],
     [ "_restoreManualHardwareResources", "class_ogre_1_1_scene_manager.html#a315288f34c602a3242edfe13354748bc", null ],
     [ "_resumeRendering", "class_ogre_1_1_scene_manager.html#a27f763bb92fef8b1238e2272889ba58d", null ],
+    [ "_setAtmosphere", "class_ogre_1_1_scene_manager.html#ae57a38bd2f7b48366ccd62ef42e7d72f", null ],
     [ "_setCamerasInProgress", "class_ogre_1_1_scene_manager.html#a9899cd0badfaa70088d4a27b8592eb82", null ],
     [ "_setCurrentCompositorPass", "class_ogre_1_1_scene_manager.html#acdd809e69cbbc4b565a27b8edef98ad1", null ],
     [ "_setCurrentRenderStage", "class_ogre_1_1_scene_manager.html#a77f751eb7bce6624985c304f878d51d9", null ],
-    [ "_setCurrentShadowNode", "class_ogre_1_1_scene_manager.html#ae333535bc17cb63a4500d4301b7270a0", null ],
+    [ "_setCurrentShadowNode", "class_ogre_1_1_scene_manager.html#aa23534c58043177bd98177efc3b0f34c", null ],
     [ "_setDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#ab20c0ee49a853145d3350e6e32c59f32", null ],
     [ "_setForwardPlusEnabledInPass", "class_ogre_1_1_scene_manager.html#a507d273b53104fb5b8c835bc0c7ce73a", null ],
     [ "_setLightCullingVisibility", "class_ogre_1_1_scene_manager.html#aa484c6a44eaae0ec7ce646b51d6dc8c3", null ],
@@ -74,11 +75,12 @@ var class_ogre_1_1_scene_manager =
     [ "_setRefractions", "class_ogre_1_1_scene_manager.html#a9c12be4929f32f819b60801c0d93ab9a", null ],
     [ "_suppressRenderStateChanges", "class_ogre_1_1_scene_manager.html#a6753ea2b52715774b7fdd59da232917a", null ],
     [ "_updateWorkerThread", "class_ogre_1_1_scene_manager.html#a9959c0abe638bebd7ad2a30abc23ca2e", null ],
+    [ "_warmUpShaders", "class_ogre_1_1_scene_manager.html#a452210f8cda18ae14867bb1d637e1ff6", null ],
     [ "addListener", "class_ogre_1_1_scene_manager.html#a6b54e34b6a8e72d4c1456bda016731ad", null ],
     [ "addLodListener", "class_ogre_1_1_scene_manager.html#a2ac761cb112de51be26c54609de3c83a", null ],
     [ "addRenderObjectListener", "class_ogre_1_1_scene_manager.html#ab73819442f7f3540f52431064e6b1a97", null ],
     [ "addRenderQueueListener", "class_ogre_1_1_scene_manager.html#ae60242c5d130f884cd605d3393186df6", null ],
-    [ "clearFrameData", "class_ogre_1_1_scene_manager.html#a1200037971723674d993871980e0516a", null ],
+    [ "clearFrameData", "class_ogre_1_1_scene_manager.html#ae6382cdc89b215c451fc68e6a1cf2278", null ],
     [ "clearScene", "class_ogre_1_1_scene_manager.html#a01ba0aad5090ed0a8ff5e9c3d24fa924", null ],
     [ "createAABBQuery", "class_ogre_1_1_scene_manager.html#aba7931f453bc3e6ce2d340b62265973c", null ],
     [ "createAnimation", "class_ogre_1_1_scene_manager.html#aa9509d9c69659cfa5ee4a09532e461ea", null ],
@@ -92,7 +94,7 @@ var class_ogre_1_1_scene_manager =
     [ "createEntity", "class_ogre_1_1_scene_manager.html#a942371c3418e00862e25e3038b8c34dc", null ],
     [ "createIntersectionQuery", "class_ogre_1_1_scene_manager.html#a330ae308e614a06f201e1c460014b8c7", null ],
     [ "createItem", "class_ogre_1_1_scene_manager.html#a2e241b0afc26f04733c70e7c453b8787", null ],
-    [ "createItem", "class_ogre_1_1_scene_manager.html#a096a0b8744464d12eecc7c8bf5059684", null ],
+    [ "createItem", "class_ogre_1_1_scene_manager.html#aff2ceebf9755716d814d867e810e0269", null ],
     [ "createLight", "class_ogre_1_1_scene_manager.html#a7399c836bf57186f171f4eb456c7fe4d", null ],
     [ "createManualObject", "class_ogre_1_1_scene_manager.html#a58defccc8c64e751db9b32a51c39c916", null ],
     [ "createMovableObject", "class_ogre_1_1_scene_manager.html#a70456cfbc5e944ab3e98e8d725e6f761", null ],
@@ -105,28 +107,26 @@ var class_ogre_1_1_scene_manager =
     [ "createSceneNode", "class_ogre_1_1_scene_manager.html#a6e3a146e09708d7fab2536db8ddd7f36", null ],
     [ "createSkeletonInstance", "class_ogre_1_1_scene_manager.html#a5fdfd9e790d2630ce07fffd8fb5a84f1", null ],
     [ "createSphereQuery", "class_ogre_1_1_scene_manager.html#ab50462941a082ff4ff4f90b4d2f99009", null ],
-    [ "createStaticGeometry", "class_ogre_1_1_scene_manager.html#abdc023851ef3781b0ab445f9c02966b7", null ],
-    [ "createTagPoint", "class_ogre_1_1_scene_manager.html#aa8569e0c88f77b6bcc2b9d3c81a44801", null ],
-    [ "createWireAabb", "class_ogre_1_1_scene_manager.html#a3da5963c455a681699b00bdbba07c416", null ],
+    [ "createTagPoint", "class_ogre_1_1_scene_manager.html#ab289e99dd8aad3fd80deccfc93eb60b3", null ],
+    [ "createWireAabb", "class_ogre_1_1_scene_manager.html#af799e7b51fb404a358944fe63ab7672a", null ],
     [ "cullLights", "class_ogre_1_1_scene_manager.html#a97b975559cf03c869e70fdcbe38c07ce", null ],
-    [ "defragmentMemoryPools", "class_ogre_1_1_scene_manager.html#acbefe70bbd0190802da5a531abdac4c7", null ],
-    [ "destroyAllAnimations", "class_ogre_1_1_scene_manager.html#a019a31618f2285f79be2b414488c04c3", null ],
-    [ "destroyAllAnimationStates", "class_ogre_1_1_scene_manager.html#aa60a84672be1f532323cdb5dbfdc2c66", null ],
-    [ "destroyAllBillboardChains", "class_ogre_1_1_scene_manager.html#a2c01b8c2d82759fb875089c93df491a4", null ],
-    [ "destroyAllBillboardSets", "class_ogre_1_1_scene_manager.html#a62742f3922523e75b72f6e8303fea251", null ],
-    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#a9cb93862284e7443b94eaabdef21564a", null ],
-    [ "destroyAllDecals", "class_ogre_1_1_scene_manager.html#a52dff1f4f8829d1337d174eb4f890196", null ],
-    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#a1a77be68ccbfc90e2e1aed04340db4dc", null ],
-    [ "destroyAllItems", "class_ogre_1_1_scene_manager.html#a20f632314554702973089c54ba815d68", null ],
-    [ "destroyAllLights", "class_ogre_1_1_scene_manager.html#a723da9119c26f5022e3a2818611e9aa0", null ],
-    [ "destroyAllManualObjects", "class_ogre_1_1_scene_manager.html#ab3e151b6d94feb6648b8c817ba485238", null ],
-    [ "destroyAllMovableObjects", "class_ogre_1_1_scene_manager.html#af985062a80dbc20d8fe523be166ecca6", null ],
+    [ "defragmentMemoryPools", "class_ogre_1_1_scene_manager.html#ad6bdefcfe64f080519d42f7082c232c1", null ],
+    [ "destroyAllAnimations", "class_ogre_1_1_scene_manager.html#a7c69befc9541ac1d62f8514444ab4382", null ],
+    [ "destroyAllAnimationStates", "class_ogre_1_1_scene_manager.html#a7d1f49ae1e1beaa6016873ecf13d2086", null ],
+    [ "destroyAllBillboardChains", "class_ogre_1_1_scene_manager.html#ac1e639ded8260661408b498f041d701d", null ],
+    [ "destroyAllBillboardSets", "class_ogre_1_1_scene_manager.html#a2c020b93723f94cb548a6656bb550e75", null ],
+    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#aaeca6aaeb426c53e5f740fca5d3acbf3", null ],
+    [ "destroyAllDecals", "class_ogre_1_1_scene_manager.html#abfc21872f05d867b3f8c38cf67b0798c", null ],
+    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#aecdd88484a39195a9e3537923c2bf267", null ],
+    [ "destroyAllItems", "class_ogre_1_1_scene_manager.html#aa542fb518afb5f148d6aa3a4c26bc75e", null ],
+    [ "destroyAllLights", "class_ogre_1_1_scene_manager.html#a8047e4aab5a8991410e0ec32c21dedc7", null ],
+    [ "destroyAllManualObjects", "class_ogre_1_1_scene_manager.html#a90caaf7b2618f1c17acf7799fc9f8cd2", null ],
+    [ "destroyAllMovableObjects", "class_ogre_1_1_scene_manager.html#afc6593e55115bf3780865d9477a0654a", null ],
     [ "destroyAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a8aca5477f30dd55321a101f25c6a5ee2", null ],
-    [ "destroyAllParticleSystems", "class_ogre_1_1_scene_manager.html#a98dbd81cd9867b1032e02e1780b6eb49", null ],
-    [ "destroyAllRectangle2D", "class_ogre_1_1_scene_manager.html#ab2673459d64d17f47b1aec0920f8e899", null ],
-    [ "destroyAllRibbonTrails", "class_ogre_1_1_scene_manager.html#a12e41109a26094ffe128beb5b6898f95", null ],
-    [ "destroyAllStaticGeometry", "class_ogre_1_1_scene_manager.html#a64f54ea048af80532212c8f60bea95d6", null ],
-    [ "destroyAllWireAabbs", "class_ogre_1_1_scene_manager.html#a75ee4d81b2354710cbcb8462992d93b2", null ],
+    [ "destroyAllParticleSystems", "class_ogre_1_1_scene_manager.html#a653364760a4df8af5c2d0d6511fb91b7", null ],
+    [ "destroyAllRectangle2D", "class_ogre_1_1_scene_manager.html#acd0f342e3cc683f7bcbe15d1ddbce5b3", null ],
+    [ "destroyAllRibbonTrails", "class_ogre_1_1_scene_manager.html#a4801c38cb6be7c6a761ae996dc7d9993", null ],
+    [ "destroyAllWireAabbs", "class_ogre_1_1_scene_manager.html#a489fcdb9a59e542a0a09be7bdac2a2ef", null ],
     [ "destroyAnimation", "class_ogre_1_1_scene_manager.html#a7ac4e76d36c8f059d7389bf1233563b5", null ],
     [ "destroyAnimationState", "class_ogre_1_1_scene_manager.html#a22a3f58bff113aaac870c18741f7cd76", null ],
     [ "destroyBillboardChain", "class_ogre_1_1_scene_manager.html#a570a5bfc2b2285cf38974dc82db416c9", null ],
@@ -145,11 +145,7 @@ var class_ogre_1_1_scene_manager =
     [ "destroyRibbonTrail", "class_ogre_1_1_scene_manager.html#a3559e67959d2e5d8ddf10b9e0556e93a", null ],
     [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c", null ],
     [ "destroySkeletonInstance", "class_ogre_1_1_scene_manager.html#a911db15a672db3ebb4837840ed2c5bf0", null ],
-    [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#ae4f180b40f4bf55669f9842fe922a003", null ],
-    [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#ad95c77b37c0da0b469b955aac98c46bf", null ],
     [ "destroyWireAabb", "class_ogre_1_1_scene_manager.html#aa12bb6b0b9cf79cf8aaa1f454cea9116", null ],
-    [ "estimateWorldGeometry", "class_ogre_1_1_scene_manager.html#a1257fd328d54908eeb45398b3191f92b", null ],
-    [ "estimateWorldGeometry", "class_ogre_1_1_scene_manager.html#abdf303a6b80c95fabfae679f0a9898f7", null ],
     [ "executeUserScalableTask", "class_ogre_1_1_scene_manager.html#a040241bad11b74f5ba8971fb146f8c6d", null ],
     [ "extractAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a1c55f5e97c66261de71c979db64f6355", null ],
     [ "extractMovableObject", "class_ogre_1_1_scene_manager.html#a874431ce04c34fa6dcbdb2ed1420b168", null ],
@@ -157,104 +153,87 @@ var class_ogre_1_1_scene_manager =
     [ "findCameraNoThrow", "class_ogre_1_1_scene_manager.html#a2025ed87eaea384815e331dbff5f561b", null ],
     [ "findMovableObjects", "class_ogre_1_1_scene_manager.html#adab6a83be3e4045890ed16dd80023ea7", null ],
     [ "findSceneNodes", "class_ogre_1_1_scene_manager.html#adca3e6a51e42c0f7383f7d92c4a79377", null ],
-    [ "getAmbientLightHemisphereDir", "class_ogre_1_1_scene_manager.html#a62850b1a3e8255f6c6524e532ed5ed1b", null ],
-    [ "getAmbientLightLowerHemisphere", "class_ogre_1_1_scene_manager.html#af45877a86653c0dcf35165f10fdceadf", null ],
-    [ "getAmbientLightUpperHemisphere", "class_ogre_1_1_scene_manager.html#afc2f8c3290cbb504699c165100a4619a", null ],
+    [ "getAmbientLightHemisphereDir", "class_ogre_1_1_scene_manager.html#afe7543bcc25f74a609507dfc357d3973", null ],
+    [ "getAmbientLightLowerHemisphere", "class_ogre_1_1_scene_manager.html#afec9e0e60b7ebc74d75413ad90d88b1f", null ],
+    [ "getAmbientLightUpperHemisphere", "class_ogre_1_1_scene_manager.html#a9a9fc4274bd15279f3eef6d1b908fa88", null ],
     [ "getAnimation", "class_ogre_1_1_scene_manager.html#a0cf942914f681a54cce83bad04906798", null ],
-    [ "getAnimationIterator", "class_ogre_1_1_scene_manager.html#ab28450738168fe330709ad0d090df6b5", null ],
+    [ "getAnimationIterator", "class_ogre_1_1_scene_manager.html#a525a0cf8f956d7c3a9ce8ad47cc11ed7", null ],
     [ "getAnimations", "class_ogre_1_1_scene_manager.html#a8c46aaf43efdf676ea590bbec79b514c", null ],
     [ "getAnimationState", "class_ogre_1_1_scene_manager.html#a42e72c9a7dcf9e31f176d6fd69820633", null ],
-    [ "getAnimationStateIterator", "class_ogre_1_1_scene_manager.html#aa48fb79e236cd76927d9e92f51a82fdf", null ],
-    [ "getCameraIterator", "class_ogre_1_1_scene_manager.html#a02d7d29cc4bc8ee4cbe40d16a984291c", null ],
+    [ "getAnimationStateIterator", "class_ogre_1_1_scene_manager.html#ab0360b83e6d67faae01f70ea7b925146", null ],
+    [ "getAtmosphere", "class_ogre_1_1_scene_manager.html#aa1aa76d962057bf5dab222e7ddc001f2", null ],
+    [ "getAtmosphereRaw", "class_ogre_1_1_scene_manager.html#a8afa979cfab6ba8c0fdeda2f11e28db7", null ],
+    [ "getCameraIterator", "class_ogre_1_1_scene_manager.html#a82f2e6f1a388c3b1937039cf0e42c63c", null ],
     [ "getCameras", "class_ogre_1_1_scene_manager.html#ab7d0636b79f0ae7cc2cae4b92c664cc6", null ],
-    [ "getCamerasInProgress", "class_ogre_1_1_scene_manager.html#a22e12455f2cfefa6e33d042056d07ec2", null ],
-    [ "getCompositorTextures", "class_ogre_1_1_scene_manager.html#aa95c1e1b4cb55211cc4a6b17ca270dc3", null ],
-    [ "getCurrentCastersBox", "class_ogre_1_1_scene_manager.html#aafb92ea96a78a01101cee2b1ce81759b", null ],
-    [ "getCurrentCompositorPass", "class_ogre_1_1_scene_manager.html#aaa7f35ce2f441368589b2ab48d068e02", null ],
-    [ "getCurrentPassDepthTextureNoMsaa", "class_ogre_1_1_scene_manager.html#a40a147da647e565ccdf7dc0869d62513", null ],
-    [ "getCurrentPrePassDepthTexture", "class_ogre_1_1_scene_manager.html#a54121e741624731fa460b45ddeaa3e27", null ],
-    [ "getCurrentPrePassMode", "class_ogre_1_1_scene_manager.html#aa622bd9607691def94c1954c5ca90be6", null ],
-    [ "getCurrentPrePassTextures", "class_ogre_1_1_scene_manager.html#a50643a6f94ba5ff2edcf69cb0e401185", null ],
-    [ "getCurrentRefractionsTexture", "class_ogre_1_1_scene_manager.html#a0d2c3ee352d2bb94df5cec30856aeba2", null ],
-    [ "getCurrentShadowNode", "class_ogre_1_1_scene_manager.html#aa15d22f9999e639513a09aa19c6ac2ba", null ],
-    [ "getCurrentSsrTexture", "class_ogre_1_1_scene_manager.html#aab931bdee7048dcaaf6031fb8702155e", null ],
-    [ "getCurrentViewport0", "class_ogre_1_1_scene_manager.html#a70b6bf1308265f1e15705f1be32aed44", null ],
-    [ "getDecalsDiffuse", "class_ogre_1_1_scene_manager.html#a99f32c5dc4717bdaea4dfa6f13eec151", null ],
-    [ "getDecalsEmissive", "class_ogre_1_1_scene_manager.html#a89dcc1f1ba9edf96523eca20e18e0a12", null ],
-    [ "getDecalsNormals", "class_ogre_1_1_scene_manager.html#a4f60f1c9777dd2895435e423f17d52e7", null ],
+    [ "getCamerasInProgress", "class_ogre_1_1_scene_manager.html#a17f57d1485b6f28bed9a7ead8d59b8e1", null ],
+    [ "getCompositorTextures", "class_ogre_1_1_scene_manager.html#a44601dc86e3c7c097554f23711b5833f", null ],
+    [ "getCurrentCastersBox", "class_ogre_1_1_scene_manager.html#ab92a5f4d67a07e621d35eadce2932b6a", null ],
+    [ "getCurrentCompositorPass", "class_ogre_1_1_scene_manager.html#a024d27a26074b9443ca2ea31bd20d392", null ],
+    [ "getCurrentPassDepthTextureNoMsaa", "class_ogre_1_1_scene_manager.html#a385a331e6d36175f40e34380311d9ede", null ],
+    [ "getCurrentPrePassDepthTexture", "class_ogre_1_1_scene_manager.html#a2944445939251525c3a89943608d6b7d", null ],
+    [ "getCurrentPrePassMode", "class_ogre_1_1_scene_manager.html#a885105ccc1b2916ddb23c6720e49a609", null ],
+    [ "getCurrentPrePassTextures", "class_ogre_1_1_scene_manager.html#aefa9a69829ea37baf535bc2f4b71eb26", null ],
+    [ "getCurrentRefractionsTexture", "class_ogre_1_1_scene_manager.html#a57b67deedb720db232e078f07331879f", null ],
+    [ "getCurrentShadowNode", "class_ogre_1_1_scene_manager.html#a8030c1cbd31c6e683f0c16435bd357ca", null ],
+    [ "getCurrentSsrTexture", "class_ogre_1_1_scene_manager.html#aa041d2301aa3c22668b60339468c95f7", null ],
+    [ "getCurrentViewport0", "class_ogre_1_1_scene_manager.html#a11d9f44d40c3c8701e44e7f6fd2ba18f", null ],
+    [ "getDecalsDiffuse", "class_ogre_1_1_scene_manager.html#aa988feb7450645f788e58fe2f17af8ce", null ],
+    [ "getDecalsEmissive", "class_ogre_1_1_scene_manager.html#a54f1a83c0d4abe6eb52f8f73a56dba50", null ],
+    [ "getDecalsNormals", "class_ogre_1_1_scene_manager.html#af755f859840603f48bd8d7e573ae128d", null ],
     [ "getDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#a91dee910ef9412d09800e11b4c5f569c", null ],
-    [ "getDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#a0fec5de5b1af8423dbdae70fa1d18954", null ],
-    [ "getDummySceneNode", "class_ogre_1_1_scene_manager.html#a3f5dfbe1ffb69ddf20d1b975aaa5ac87", null ],
-    [ "getEnvFeatures", "class_ogre_1_1_scene_manager.html#a07f0d973ae444360bcf454f421169bcb", null ],
-    [ "getFindVisibleObjects", "class_ogre_1_1_scene_manager.html#a3d7d7f344e528eea2e99481247de72c7", null ],
+    [ "getDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#aad6b3b69661d9953a97978263424a65f", null ],
+    [ "getDummySceneNode", "class_ogre_1_1_scene_manager.html#a163c2c7aa474ff59c70d93a472758f1f", null ],
+    [ "getEnvFeatures", "class_ogre_1_1_scene_manager.html#ad95420a53abc951b1ff614907b43dc3b", null ],
+    [ "getFindVisibleObjects", "class_ogre_1_1_scene_manager.html#ae0c73c882ba16527bc9e55498ec59002", null ],
     [ "getFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#ac981c1e86936cdf189150d6dabeb8f4f", null ],
-    [ "getFogColour", "class_ogre_1_1_scene_manager.html#a79464a4a9d2524b9d1ad678eeddebe97", null ],
-    [ "getFogDensity", "class_ogre_1_1_scene_manager.html#a12cb60fdad7cb792c6897f6a75f5a71a", null ],
-    [ "getFogEnd", "class_ogre_1_1_scene_manager.html#aa52eb95b1241a0ba0468287a22bd3fd8", null ],
-    [ "getFogMode", "class_ogre_1_1_scene_manager.html#a860a3c04b9b0db60a78f08743a104a94", null ],
-    [ "getFogStart", "class_ogre_1_1_scene_manager.html#adcfa98c914fe6e6f67a21fe144bd281d", null ],
-    [ "getForwardPlus", "class_ogre_1_1_scene_manager.html#a86b3b062ce0b54ea8c71d5d40ed00a78", null ],
-    [ "getGlobalLightList", "class_ogre_1_1_scene_manager.html#aefc67b4b417b9d5ade6d6188235bdf8f", null ],
-    [ "getId", "class_ogre_1_1_scene_manager.html#ab152c8f646a835c2f88585ad4fe0413a", null ],
+    [ "getForwardPlus", "class_ogre_1_1_scene_manager.html#affa7a4596f373629fcb78519dd66f1ff", null ],
+    [ "getGlobalLightList", "class_ogre_1_1_scene_manager.html#a6af13fb4aa57c62802b840ec87e8109c", null ],
     [ "getLightClippingPlanes", "class_ogre_1_1_scene_manager.html#a430db63ba198fcaca82ea94c8e5f0210", null ],
-    [ "getLightMask", "class_ogre_1_1_scene_manager.html#a8b218f3cb84919377e7174c28407e42a", null ],
+    [ "getLightMask", "class_ogre_1_1_scene_manager.html#acd30d431eb84e9c00d3e3051dfcb7631", null ],
     [ "getLightScissorRect", "class_ogre_1_1_scene_manager.html#aed6fa4bfde15ddcc956bf8d69082064b", null ],
     [ "getMinMaxDepthRange", "class_ogre_1_1_scene_manager.html#a7c3f378c66d1266970320d8fb04278b0", null ],
     [ "getMovableObjectIterator", "class_ogre_1_1_scene_manager.html#af19c32fbc0adc0fa28d8e6c26d9800cb", null ],
-    [ "getName", "class_ogre_1_1_scene_manager.html#a8d29d1e2d954090ce2fba768b7f30c02", null ],
-    [ "getNumCompositorTextures", "class_ogre_1_1_scene_manager.html#af8b9ac37458ce1911947e1c077187fec", null ],
+    [ "getName", "class_ogre_1_1_scene_manager.html#a62c4a11d535277d361d1ce376675e4d1", null ],
+    [ "getNumCompositorTextures", "class_ogre_1_1_scene_manager.html#a4b25cc84294cfccc0e963289521f7b6a", null ],
     [ "getNumWorkerThreads", "class_ogre_1_1_scene_manager.html#a4ac962924e49d9686471e3e639177129", null ],
     [ "getOption", "class_ogre_1_1_scene_manager.html#a2ea53a860f373185f5a46239f579a361", null ],
     [ "getOptionKeys", "class_ogre_1_1_scene_manager.html#a7c8ff6b5c19eb9eeef9d5a6c9fca9fe8", null ],
     [ "getOptionValues", "class_ogre_1_1_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93", null ],
-    [ "getRadialDensityMask", "class_ogre_1_1_scene_manager.html#a7d71c96bd777fb4e2c1eac1c286e522f", null ],
-    [ "getRelativeOrigin", "class_ogre_1_1_scene_manager.html#a045cc6cee9d3db9c59d0e14523368eb8", null ],
-    [ "getRenderQueue", "class_ogre_1_1_scene_manager.html#a935347e3d8a5af785e819abb901882f6", null ],
+    [ "getRadialDensityMask", "class_ogre_1_1_scene_manager.html#a334459abc4920eb1bdd75bda69f69eb2", null ],
+    [ "getRelativeOrigin", "class_ogre_1_1_scene_manager.html#aaa473a1b76a9eb082cfbb31b7390349f", null ],
+    [ "getRenderQueue", "class_ogre_1_1_scene_manager.html#ae1dc2f3757619b4abb143f7ad68cff90", null ],
     [ "getRootSceneNode", "class_ogre_1_1_scene_manager.html#acc8c5b44ac2874ca069800378d2705a7", null ],
     [ "getSceneNode", "class_ogre_1_1_scene_manager.html#ae3ac7fea64e00ce827e90b178c6223a9", null ],
     [ "getSceneNode", "class_ogre_1_1_scene_manager.html#a1efb01b456181bff954406a6fb006097", null ],
-    [ "getShadowColour", "class_ogre_1_1_scene_manager.html#a474ad27fd3e94fe42bb94857a5f4eab1", null ],
-    [ "getShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a4c8d7b3656c9bdc0910eede3707ee0f5", null ],
-    [ "getShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a70f92eed233e8131c28b93a1a8d144c1", null ],
-    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#a9db2b873fe3a9a4db5c824f813efbcae", null ],
-    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#aadcf0e82479037779758261648b5e6d7", null ],
+    [ "getShadowColour", "class_ogre_1_1_scene_manager.html#afb3c2757a3ecb21d4ef193bd5b71bd6d", null ],
+    [ "getShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#ad24dc352ecec769b738df9d1612b1202", null ],
+    [ "getShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#ad89081c54d3408b72c0cbf7b66917248", null ],
+    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#aa1911e4a72e0781ee68225de480ca60c", null ],
+    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#aadc40a279ac50ed638f8fe88ef7358e0", null ],
     [ "getShowBoundingBoxes", "class_ogre_1_1_scene_manager.html#aa6008c82cd40e85f1b1c38d7929ec2ba", null ],
-    [ "getSky", "class_ogre_1_1_scene_manager.html#aa81b2df11455e521a3b0f20d3d32e133", null ],
-    [ "getSkyMaterial", "class_ogre_1_1_scene_manager.html#a31ab1328d25b3374d91a4e77f671478e", null ],
-    [ "getSkyMethod", "class_ogre_1_1_scene_manager.html#a2abfe2af49de9dd7139ec0aea244b410", null ],
-    [ "getSphericalHarmonics", "class_ogre_1_1_scene_manager.html#a210282d4f484267c0da27bcce2fe4570", null ],
-    [ "getStaticGeometry", "class_ogre_1_1_scene_manager.html#afb4874ff4b526ccbc83a6dd8acd6dcdd", null ],
+    [ "getSky", "class_ogre_1_1_scene_manager.html#ac19e5e258d60b9546f013c3851553ef1", null ],
+    [ "getSkyMaterial", "class_ogre_1_1_scene_manager.html#a5380b5752fbdc38c0476d715f3e963d7", null ],
+    [ "getSkyMethod", "class_ogre_1_1_scene_manager.html#ac828cd3ecb5edb1255bd6692b4b4f2f7", null ],
+    [ "getSphericalHarmonics", "class_ogre_1_1_scene_manager.html#a45071692da3ff5d2706c2e936c306ba0", null ],
     [ "getSuggestedViewpoint", "class_ogre_1_1_scene_manager.html#add6fe27d7a9500aafbe9325c21985801", null ],
-    [ "getTypeName", "class_ogre_1_1_scene_manager.html#a2f139de7c96a237754f075dbca80670e", null ],
-    [ "getVisibilityMask", "class_ogre_1_1_scene_manager.html#a0da39851ae801a1a561a2dc8a269532b", null ],
+    [ "getTypeName", "class_ogre_1_1_scene_manager.html#a6b9cc60e91cb9e09597f75d8c6a99cce", null ],
+    [ "getVisibilityMask", "class_ogre_1_1_scene_manager.html#acb7dd8e3e86102503d4c990433047ad8", null ],
     [ "hasAnimation", "class_ogre_1_1_scene_manager.html#a689e655688df190c38eb3437c7a8e94e", null ],
     [ "hasAnimationState", "class_ogre_1_1_scene_manager.html#affa968418639b742f299cf6cb553aa73", null ],
     [ "hasMovableObject", "class_ogre_1_1_scene_manager.html#a17bf05431cd6901c4b2fc9c89a42de67", null ],
     [ "hasOption", "class_ogre_1_1_scene_manager.html#a6c9731d50869bd17fd55dfbf0f54db78", null ],
-    [ "hasStaticGeometry", "class_ogre_1_1_scene_manager.html#a16a9e2d2738ef22c23a72f5c214d19c8", null ],
     [ "injectMovableObject", "class_ogre_1_1_scene_manager.html#af13eb691a7bdd67e17a402dee98c4b5f", null ],
-    [ "isCurrentShadowNodeReused", "class_ogre_1_1_scene_manager.html#a2d8f7e94f73720dc0f94bc34610543fa", null ],
-    [ "isDecalsDiffuseEmissiveMerged", "class_ogre_1_1_scene_manager.html#ae51472468ae83562f0a70e0bc8ca3add", null ],
-    [ "isLateMaterialResolving", "class_ogre_1_1_scene_manager.html#a64a77e6deae28a8fdc8068e3dd063419", null ],
-    [ "isSkyEnabled", "class_ogre_1_1_scene_manager.html#a27d90c6acbd70ed5a84a53bce7c4aca2", null ],
-    [ "isUsingInstancedStereo", "class_ogre_1_1_scene_manager.html#a0dfe820c569ee6b74419af8ee43deda0", null ],
+    [ "isDecalsDiffuseEmissiveMerged", "class_ogre_1_1_scene_manager.html#a026ef6835c39e17cb8a3ab485a653b0b", null ],
+    [ "isSkyEnabled", "class_ogre_1_1_scene_manager.html#aca98bc5c9414a63e9e7cd007e2f848ad", null ],
+    [ "isUsingInstancedStereo", "class_ogre_1_1_scene_manager.html#a635375da32f1c76624f46b3678ee494d", null ],
     [ "notifyStaticAabbDirty", "class_ogre_1_1_scene_manager.html#a09cefefe52f0a24f5df51d8edc36df25", null ],
     [ "notifyStaticDirty", "class_ogre_1_1_scene_manager.html#a464c4d6f1f2761d8d3b715df0591b96a", null ],
+    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a0eefe02b720cef4bee630ab97c6a0125", null ],
+    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a5d903e46743ff7af72594b907fc8d04d", null ],
+    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a92234d6a25f84cc223c710f3c0724794", null ],
+    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a32535513fb44c5a02e41b4e1f38594ec", null ],
+    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a585404a6e220b4d141d8c4e3e0d7bb74", null ],
     [ "OGRE_MUTEX", "class_ogre_1_1_scene_manager.html#a9b10b7fef2893e75acc083415df70446", null ],
-    [ "operator delete", "class_ogre_1_1_scene_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-    [ "operator delete", "class_ogre_1_1_scene_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-    [ "operator delete", "class_ogre_1_1_scene_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-    [ "operator delete[]", "class_ogre_1_1_scene_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-    [ "operator delete[]", "class_ogre_1_1_scene_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-    [ "operator new", "class_ogre_1_1_scene_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-    [ "operator new", "class_ogre_1_1_scene_manager.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-    [ "operator new", "class_ogre_1_1_scene_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-    [ "operator new[]", "class_ogre_1_1_scene_manager.html#adce32528577d71b228692df906ecd17c", null ],
-    [ "operator new[]", "class_ogre_1_1_scene_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
-    [ "operator()", "class_ogre_1_1_scene_manager.html#a57e0523432c6e5133ff4fc251111a60e", null ],
-    [ "operator()", "class_ogre_1_1_scene_manager.html#a0ae22596b5bd2a3faf2958ab3d109d1f", null ],
-    [ "prepareWorldGeometry", "class_ogre_1_1_scene_manager.html#a5ceb87944e7ba077e4c6ed8db8acf4cc", null ],
-    [ "prepareWorldGeometry", "class_ogre_1_1_scene_manager.html#ad9633390826daf0fb2c7a8a43abe4f01", null ],
     [ "registerSceneNodeListener", "class_ogre_1_1_scene_manager.html#aaff41e7ad0baa4f0aa50f4b3e7048d63", null ],
     [ "removeListener", "class_ogre_1_1_scene_manager.html#a4437b11b78eae8f5db205aa89c0235ee", null ],
     [ "removeLodListener", "class_ogre_1_1_scene_manager.html#a25cc1bb36997b722fc60efc7903f3760", null ],
@@ -269,10 +248,9 @@ var class_ogre_1_1_scene_manager =
     [ "setDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#a46c5cbc33b0f498ed01670289e87584c", null ],
     [ "setFindVisibleObjects", "class_ogre_1_1_scene_manager.html#a04c8414da02aec3e3f98acd013917ed2", null ],
     [ "setFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#a2a4d997503b651187f2e129cd5eeb7ad", null ],
-    [ "setFog", "class_ogre_1_1_scene_manager.html#ab804195c05873da617dcd16198a63d1c", null ],
+    [ "setFog", "class_ogre_1_1_scene_manager.html#af6a241d39e3a26f31bafcd444481b157", null ],
     [ "setForward3D", "class_ogre_1_1_scene_manager.html#a7b4cbdad7664b8747f1929dbec29c046", null ],
     [ "setForwardClustered", "class_ogre_1_1_scene_manager.html#a4fd7c7abebcd867e462035b32458983a", null ],
-    [ "setLateMaterialResolving", "class_ogre_1_1_scene_manager.html#a86c1371039d40e139a37b2b174538978", null ],
     [ "setLightMask", "class_ogre_1_1_scene_manager.html#aafb46b1100b787f2b032407d889251b9", null ],
     [ "setOption", "class_ogre_1_1_scene_manager.html#a34f3ddda75dcf75d5c5176446b3316a8", null ],
     [ "setRadialDensityMask", "class_ogre_1_1_scene_manager.html#ab703066810e23f4284e1662fe58ae8f3", null ],
@@ -281,22 +259,19 @@ var class_ogre_1_1_scene_manager =
     [ "setShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a9d220fa31bf0d95ad65558936c71a194", null ],
     [ "setShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a893663f55c2b4a29467cff25b9b1b3f4", null ],
     [ "setShadowFarDistance", "class_ogre_1_1_scene_manager.html#a0e593d05e2f892b8fc3bfca917a75fef", null ],
-    [ "setShadowTextureCasterMaterial", "class_ogre_1_1_scene_manager.html#a9f0cde141313583e65561abdfae6a0ec", null ],
     [ "setShadowTextureFadeEnd", "class_ogre_1_1_scene_manager.html#a237a09e65919b808473c543fb886723f", null ],
     [ "setShadowTextureFadeStart", "class_ogre_1_1_scene_manager.html#a72fa019aa4efbc6943842efcf5f38078", null ],
     [ "setSky", "class_ogre_1_1_scene_manager.html#a3dc2f4478ab8741bdcf02c9008ef7809", null ],
     [ "setSky", "class_ogre_1_1_scene_manager.html#ab8c1c6962ad94e28ac4a202f1fd16772", null ],
     [ "setSphericalHarmonics", "class_ogre_1_1_scene_manager.html#a5447c974f3384f0b7550a2f776a25b28", null ],
     [ "setVisibilityMask", "class_ogre_1_1_scene_manager.html#a7c5e69ee25b1e34eadd088d7d58ef02d", null ],
-    [ "setWorldGeometry", "class_ogre_1_1_scene_manager.html#accb0fdfbd1f61aa4d3d6e1f4625e1f9c", null ],
-    [ "setWorldGeometry", "class_ogre_1_1_scene_manager.html#a9b7ebcecf64452f59211f45d4ec33576", null ],
     [ "showBoundingBoxes", "class_ogre_1_1_scene_manager.html#a487859007d68fe9f261aea1645252563", null ],
-    [ "shrinkToFitMemoryPools", "class_ogre_1_1_scene_manager.html#abd76eb23cf6c7eadd9447ba07975e0ee", null ],
+    [ "shrinkToFitMemoryPools", "class_ogre_1_1_scene_manager.html#a1466e16a5ce667fea5765d67e4654287", null ],
     [ "unregisterSceneNodeListener", "class_ogre_1_1_scene_manager.html#ac660da6d88e53b19c0062884705222ca", null ],
     [ "updateAllAnimations", "class_ogre_1_1_scene_manager.html#a393dbe126bfaaf7f5aa4712a84d3facd", null ],
     [ "updateAllBounds", "class_ogre_1_1_scene_manager.html#a5de4ecb4955dcf164cfeb69c457716ee", null ],
     [ "updateAllLods", "class_ogre_1_1_scene_manager.html#a77ce1584abf7edd2896e7f7c0d0bd629", null ],
-    [ "updateAllTagPoints", "class_ogre_1_1_scene_manager.html#aa99abd1ab437720f0b1056080736b164", null ],
+    [ "updateAllTagPoints", "class_ogre_1_1_scene_manager.html#a8612bb2ff02cf6e5ff976ebbdd392921", null ],
     [ "updateAllTransforms", "class_ogre_1_1_scene_manager.html#a1f59ebdfaadbe33f713d754737041654", null ],
     [ "updateSceneGraph", "class_ogre_1_1_scene_manager.html#a3cbd2750082529aed2375531a4d5d9cd", null ],
     [ "waitForPendingUserScalableTask", "class_ogre_1_1_scene_manager.html#a11c832526246a71e73cd517bff928a64", null ],
