@@ -5,18 +5,17 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "CommandBuffer", "dir_fe4af7eb106a9d97f6b7372ef02152e3.html", "dir_fe4af7eb106a9d97f6b7372ef02152e3" ],
     [ "Compositor", "dir_a43e09d9577a58939e1624d8e39f3bd4.html", "dir_a43e09d9577a58939e1624d8e39f3bd4" ],
     [ "Compute", "dir_b4f354ca4c4adb46381edc31f282c310.html", "dir_b4f354ca4c4adb46381edc31f282c310" ],
-    [ "Deprecated", "dir_882e490fc42778f674a21d3536bf54f0.html", "dir_882e490fc42778f674a21d3536bf54f0" ],
     [ "Emscripten", "dir_79b9f1fa915b84e842a2276d6427cc3f.html", "dir_79b9f1fa915b84e842a2276d6427cc3f" ],
     [ "GLX", "dir_d27246c2bb2f1071acafddf2b5863b1d.html", "dir_d27246c2bb2f1071acafddf2b5863b1d" ],
     [ "gtk", "dir_6df6a9f1943c33c15dcb8b174fa69eeb.html", "dir_6df6a9f1943c33c15dcb8b174fa69eeb" ],
     [ "iOS", "dir_30a0b9c4d1670a743c5a5941134e173e.html", "dir_30a0b9c4d1670a743c5a5941134e173e" ],
     [ "Math", "dir_c58b6c9650df91c2a14d0e057bd4a946.html", "dir_c58b6c9650df91c2a14d0e057bd4a946" ],
-    [ "NaCl", "dir_0f299109dd98f2c18b90e1f55e8e3f49.html", "dir_0f299109dd98f2c18b90e1f55e8e3f49" ],
     [ "OSX", "dir_f04c5617fd6e4df5de7d0ae6c161b38c.html", "dir_f04c5617fd6e4df5de7d0ae6c161b38c" ],
     [ "Threading", "dir_981382ac5f3a1ca3a953b14216ee58ea.html", "dir_981382ac5f3a1ca3a953b14216ee58ea" ],
     [ "Vao", "dir_915f5e2f7b6c1845cb870011199325d4.html", "dir_915f5e2f7b6c1845cb870011199325d4" ],
     [ "WIN32", "dir_1c779f42a2ea96714ae1b39af1d220c1.html", "dir_1c779f42a2ea96714ae1b39af1d220c1" ],
     [ "Ogre.h", "_ogre_8h.html", null ],
+    [ "OgreAbiUtils.h", "_ogre_abi_utils_8h.html", "_ogre_abi_utils_8h" ],
     [ "OgreAlignedAllocator.h", "_ogre_aligned_allocator_8h.html", null ],
     [ "OgreAnimable.h", "_ogre_animable_8h.html", null ],
     [ "OgreAnimation.h", "_ogre_animation_8h.html", null ],
@@ -29,6 +28,7 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreAssert.h", "_ogre_assert_8h.html", "_ogre_assert_8h" ],
     [ "OgreASTCCodec.h", "_ogre_a_s_t_c_codec_8h.html", null ],
     [ "OgreAsyncTextureTicket.h", "_ogre_async_texture_ticket_8h.html", "_ogre_async_texture_ticket_8h" ],
+    [ "OgreAtmosphereComponent.h", "_ogre_atmosphere_component_8h.html", "_ogre_atmosphere_component_8h" ],
     [ "OgreAtomicObject.h", "_ogre_atomic_object_8h.html", null ],
     [ "OgreAtomicScalar.h", "_ogre_atomic_scalar_8h.html", null ],
     [ "OgreAutoParamDataSource.h", "_ogre_auto_param_data_source_8h.html", null ],
@@ -92,10 +92,8 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreGpuResource.h", "_ogre_gpu_resource_8h.html", "_ogre_gpu_resource_8h" ],
     [ "OgreHardwareBuffer.h", "_ogre_hardware_buffer_8h.html", null ],
     [ "OgreHardwareBufferManager.h", "_ogre_hardware_buffer_manager_8h.html", null ],
-    [ "OgreHardwareCounterBuffer.h", "_ogre_hardware_counter_buffer_8h.html", null ],
     [ "OgreHardwareIndexBuffer.h", "_ogre_hardware_index_buffer_8h.html", "_ogre_hardware_index_buffer_8h" ],
     [ "OgreHardwareOcclusionQuery.h", "_ogre_hardware_occlusion_query_8h.html", null ],
-    [ "OgreHardwareUniformBuffer.h", "_ogre_hardware_uniform_buffer_8h.html", null ],
     [ "OgreHardwareVertexBuffer.h", "_ogre_hardware_vertex_buffer_8h.html", "_ogre_hardware_vertex_buffer_8h" ],
     [ "OgreHeaderPrefix.h", "_ogre_header_prefix_8h.html", null ],
     [ "OgreHeaderSuffix.h", "_ogre_header_suffix_8h.html", null ],
@@ -145,8 +143,6 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreMatrix4.h", "_ogre_matrix4_8h.html", "_ogre_matrix4_8h" ],
     [ "OgreMemoryAllocatedObject.h", "_ogre_memory_allocated_object_8h.html", null ],
     [ "OgreMemoryAllocatorConfig.h", "_ogre_memory_allocator_config_8h.html", "_ogre_memory_allocator_config_8h" ],
-    [ "OgreMemoryNedAlloc.h", "_ogre_memory_ned_alloc_8h.html", null ],
-    [ "OgreMemoryNedPooling.h", "_ogre_memory_ned_pooling_8h.html", null ],
     [ "OgreMemoryStdAlloc.h", "_ogre_memory_std_alloc_8h.html", null ],
     [ "OgreMemorySTLAllocator.h", "_ogre_memory_s_t_l_allocator_8h.html", "_ogre_memory_s_t_l_allocator_8h" ],
     [ "OgreMemoryTrackAlloc.h", "_ogre_memory_track_alloc_8h.html", null ],
@@ -247,8 +243,8 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreShadowCameraSetupFocused.h", "_ogre_shadow_camera_setup_focused_8h.html", null ],
     [ "OgreShadowCameraSetupPlaneOptimal.h", "_ogre_shadow_camera_setup_plane_optimal_8h.html", null ],
     [ "OgreShadowCameraSetupPSSM.h", "_ogre_shadow_camera_setup_p_s_s_m_8h.html", null ],
-    [ "OgreShadowVolumeExtrudeProgram.h", "_ogre_shadow_volume_extrude_program_8h.html", "_ogre_shadow_volume_extrude_program_8h" ],
     [ "OgreSharedPtr.h", "_ogre_shared_ptr_8h.html", "_ogre_shared_ptr_8h" ],
+    [ "OgreSilentMemory.h", "_ogre_silent_memory_8h.html", "_ogre_silent_memory_8h" ],
     [ "OgreSimpleRenderable.h", "_ogre_simple_renderable_8h.html", null ],
     [ "OgreSimpleSpline.h", "_ogre_simple_spline_8h.html", null ],
     [ "OgreSingleton.h", "_ogre_singleton_8h.html", null ],
@@ -262,8 +258,6 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreStagingTexture.h", "_ogre_staging_texture_8h.html", null ],
     [ "OgreStagingTextureBufferImpl.h", "_ogre_staging_texture_buffer_impl_8h.html", null ],
     [ "OgreStagingTextureManager.h", "_ogre_staging_texture_manager_8h.html", "_ogre_staging_texture_manager_8h" ],
-    [ "OgreStaticFaceGroup.h", "_ogre_static_face_group_8h.html", "_ogre_static_face_group_8h" ],
-    [ "OgreStaticGeometry.h", "_ogre_static_geometry_8h.html", "_ogre_static_geometry_8h" ],
     [ "OgreSTBICodec.h", "_ogre_s_t_b_i_codec_8h.html", null ],
     [ "OgreStdHeaders.h", "_ogre_std_headers_8h.html", null ],
     [ "OgreStreamSerialiser.h", "_ogre_stream_serialiser_8h.html", "_ogre_stream_serialiser_8h" ],
