@@ -8,5 +8,5 @@ var dir_a612293e292439edfb7592851fd229f7 =
     [ "OgreEGLRenderTexture.h", "_ogre_e_g_l_render_texture_8h.html", null ],
     [ "OgreEGLSupport.h", "_ogre_e_g_l_support_8h.html", "_ogre_e_g_l_support_8h" ],
     [ "OgreEGLWindow.h", "_g_l_e_s2_2include_2_e_g_l_2_ogre_e_g_l_window_8h.html", "_g_l_e_s2_2include_2_e_g_l_2_ogre_e_g_l_window_8h" ],
-    [ "OgreGLES2Util.h", "_e_g_l_2_ogre_g_l_e_s2_util_8h.html", "_e_g_l_2_ogre_g_l_e_s2_util_8h" ]
+    [ "OgreGLES2Util.h", "_ogre_g_l_e_s2_util_8h.html", "_ogre_g_l_e_s2_util_8h" ]
 ];
\ No newline at end of file
