@@ -6,8 +6,6 @@ var dir_d90ff9c8ff6b73d6075df632a80d1163 =
     [ "OgreGLSLPreprocessor.h", "_ogre_g_l_s_l_preprocessor_8h.html", "_ogre_g_l_s_l_preprocessor_8h" ],
     [ "OgreGLSLProgram.h", "_ogre_g_l_s_l_program_8h.html", "_ogre_g_l_s_l_program_8h" ],
     [ "OgreGLSLProgramManager.h", "_ogre_g_l_s_l_program_manager_8h.html", "_ogre_g_l_s_l_program_manager_8h" ],
-    [ "OgreGLSLSeparableProgram.h", "_ogre_g_l_s_l_separable_program_8h.html", "_ogre_g_l_s_l_separable_program_8h" ],
-    [ "OgreGLSLSeparableProgramManager.h", "_ogre_g_l_s_l_separable_program_manager_8h.html", "_ogre_g_l_s_l_separable_program_manager_8h" ],
     [ "OgreGLSLShader.h", "_ogre_g_l_s_l_shader_8h.html", "_ogre_g_l_s_l_shader_8h" ],
     [ "OgreGLSLShaderFactory.h", "_ogre_g_l_s_l_shader_factory_8h.html", "_ogre_g_l_s_l_shader_factory_8h" ],
     [ "OgreGLSLShaderManager.h", "_ogre_g_l_s_l_shader_manager_8h.html", "_ogre_g_l_s_l_shader_manager_8h" ]
