@@ -1,26 +1,11 @@
 var group___memory =
 [
     [ "OgreMemoryAllocatorConfig.h", "_ogre_memory_allocator_config_8h.html", null ],
-    [ "Ogre", "namespace_ogre.html", null ],
     [ "Ogre::AlignedMemory", "class_ogre_1_1_aligned_memory.html", [
       [ "allocate", "class_ogre_1_1_aligned_memory.html#a01be2f01666893095a00393e2c167467", null ],
       [ "allocate", "class_ogre_1_1_aligned_memory.html#aa7da5d5b67d88adec855c35ff1c3b8c2", null ],
       [ "deallocate", "class_ogre_1_1_aligned_memory.html#aec9665c128b282869284a6025520adee", null ]
     ] ],
-    [ "Ogre::AllocatedObject< Alloc >", "class_ogre_1_1_allocated_object.html", [
-      [ "AllocatedObject", "class_ogre_1_1_allocated_object.html#a366445eb206e55a2199267b8b9089ebb", null ],
-      [ "~AllocatedObject", "class_ogre_1_1_allocated_object.html#a499773d35ca98b2df7c2699fc8c1bea2", null ],
-      [ "operator delete", "class_ogre_1_1_allocated_object.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_allocated_object.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_allocated_object.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_allocated_object.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_allocated_object.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_allocated_object.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_allocated_object.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_allocated_object.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_allocated_object.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_allocated_object.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ]
-    ] ],
     [ "Ogre::ArrayMemoryManager", "class_ogre_1_1_array_memory_manager.html", [
       [ "RebaseListener", "class_ogre_1_1_array_memory_manager_1_1_rebase_listener.html", [
         [ "applyRebase", "class_ogre_1_1_array_memory_manager_1_1_rebase_listener.html#aefcfd7751701e774e0ba3ba51935438d", null ],
@@ -30,7 +15,7 @@ var group___memory =
       [ "PtrdiffVec", "class_ogre_1_1_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426", null ],
       [ "ArrayMemoryManager", "class_ogre_1_1_array_memory_manager.html#a9d4cefc1bbe7c9016496e60f7ceb6bcd", null ],
       [ "~ArrayMemoryManager", "class_ogre_1_1_array_memory_manager.html#ac39c1d7b610c181e4c9b5baeef0097cc", null ],
-      [ "defragment", "class_ogre_1_1_array_memory_manager.html#a81ef5397bd517180f3f0e88f9a78633f", null ],
+      [ "defragment", "class_ogre_1_1_array_memory_manager.html#a1ff6ca754a46c4d2fe35ec737681bc26", null ],
       [ "destroy", "class_ogre_1_1_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0", null ],
       [ "getAllMemory", "class_ogre_1_1_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341", null ],
       [ "getFreeMemory", "class_ogre_1_1_array_memory_manager.html#ac639db8f3c078fa02ceb2691d4b86065", null ],
@@ -38,11 +23,11 @@ var group___memory =
       [ "getUsedMemory", "class_ogre_1_1_array_memory_manager.html#a1483bb4f495abd37502c209eecc08881", null ],
       [ "getWastedMemory", "class_ogre_1_1_array_memory_manager.html#a42fe5a861ebd6b4610189ce2be86b032", null ],
       [ "initialize", "class_ogre_1_1_array_memory_manager.html#ad680fce37ec7058f94a5a69be2e2f4c5", null ],
-      [ "shrinkToFit", "class_ogre_1_1_array_memory_manager.html#a73d117284527cab40571e73e22f05f0f", null ],
+      [ "neverDefragment", "class_ogre_1_1_array_memory_manager.html#a443f00a249cbbc4b6edf56632c5e2756", null ],
+      [ "shrinkToFit", "class_ogre_1_1_array_memory_manager.html#a1885069fab42349469ea51ea34590bad", null ],
       [ "MAX_MEMORY_SLOTS", "class_ogre_1_1_array_memory_manager.html#a738870646404c47464027863b9dea16c", null ]
     ] ],
     [ "Ogre::BoneArrayMemoryManager", "class_ogre_1_1_bone_array_memory_manager.html", [
-      [ "PtrdiffVec", "class_ogre_1_1_bone_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426", null ],
       [ "MemoryTypes", "class_ogre_1_1_bone_array_memory_manager.html#aa20b2f1745d99d3534242c64c19e5c7e", [
         [ "Owner", "class_ogre_1_1_bone_array_memory_manager.html#aa20b2f1745d99d3534242c64c19e5c7ea6b77403ae3588cc6d8f67271366327d5", null ],
         [ "Position", "class_ogre_1_1_bone_array_memory_manager.html#aa20b2f1745d99d3534242c64c19e5c7ead79d876167733f51086b408040fdc79f", null ],
@@ -58,28 +43,18 @@ var group___memory =
       ] ],
       [ "BoneArrayMemoryManager", "class_ogre_1_1_bone_array_memory_manager.html#a780996517465b98494b5671576da0bef", null ],
       [ "createNewNode", "class_ogre_1_1_bone_array_memory_manager.html#ad03ffb749fb44282e687fd5cd982a6b7", null ],
-      [ "defragment", "class_ogre_1_1_bone_array_memory_manager.html#a81ef5397bd517180f3f0e88f9a78633f", null ],
-      [ "destroy", "class_ogre_1_1_bone_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0", null ],
       [ "destroyNode", "class_ogre_1_1_bone_array_memory_manager.html#ad576942696d777aeb0589dda9c481044", null ],
-      [ "getAllMemory", "class_ogre_1_1_bone_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341", null ],
       [ "getFirstNode", "class_ogre_1_1_bone_array_memory_manager.html#a9190868192f4cd6b544832e168410768", null ],
-      [ "getFreeMemory", "class_ogre_1_1_bone_array_memory_manager.html#ac639db8f3c078fa02ceb2691d4b86065", null ],
-      [ "getNumUsedSlotsIncludingFragmented", "class_ogre_1_1_bone_array_memory_manager.html#afd91cd460057cd3a143e84c887655c26", null ],
-      [ "getUsedMemory", "class_ogre_1_1_bone_array_memory_manager.html#a1483bb4f495abd37502c209eecc08881", null ],
-      [ "getWastedMemory", "class_ogre_1_1_bone_array_memory_manager.html#a42fe5a861ebd6b4610189ce2be86b032", null ],
-      [ "initialize", "class_ogre_1_1_bone_array_memory_manager.html#ad680fce37ec7058f94a5a69be2e2f4c5", null ],
-      [ "shrinkToFit", "class_ogre_1_1_bone_array_memory_manager.html#a73d117284527cab40571e73e22f05f0f", null ],
       [ "BoneCleanupRoutines", "class_ogre_1_1_bone_array_memory_manager.html#a0ae824691bda826505d578c8e710e696", null ],
       [ "BoneInitRoutines", "class_ogre_1_1_bone_array_memory_manager.html#a54f67f154e7bc21144c1962b83063fad", null ],
-      [ "ElementsMemSize", "class_ogre_1_1_bone_array_memory_manager.html#a1f9c3b7d2dee1d619161717d8ed0cd80", null ],
-      [ "MAX_MEMORY_SLOTS", "class_ogre_1_1_bone_array_memory_manager.html#a738870646404c47464027863b9dea16c", null ]
+      [ "ElementsMemSize", "class_ogre_1_1_bone_array_memory_manager.html#a1f9c3b7d2dee1d619161717d8ed0cd80", null ]
     ] ],
     [ "Ogre::BoneMemoryManager", "class_ogre_1_1_bone_memory_manager.html", [
       [ "BoneMemoryManager", "class_ogre_1_1_bone_memory_manager.html#a4c64e11634352f03b8f6ef06c94ff800", null ],
       [ "~BoneMemoryManager", "class_ogre_1_1_bone_memory_manager.html#a2fe61696b7ed82aded3499505ce3ccb7", null ],
       [ "_growToDepth", "class_ogre_1_1_bone_memory_manager.html#a4c9581070ff4387dd6c96219c215bbb8", null ],
-      [ "applyRebase", "class_ogre_1_1_bone_memory_manager.html#a12aaf44ee4440752ecedeaea3395d7e9", null ],
-      [ "buildDiffList", "class_ogre_1_1_bone_memory_manager.html#a9126b9cf86aec8cd158b94d789fc3ed1", null ],
+      [ "applyRebase", "class_ogre_1_1_bone_memory_manager.html#a22d578b95ec5ba0122dc470f0a271403", null ],
+      [ "buildDiffList", "class_ogre_1_1_bone_memory_manager.html#a614abce97208d156393eb107c9f1fd6d", null ],
       [ "getFirstNode", "class_ogre_1_1_bone_memory_manager.html#ace3691a6bda08beeed3f3383df51a9c9", null ],
       [ "getNumDepths", "class_ogre_1_1_bone_memory_manager.html#a77a57600c46f2f0b5ac6643c7bec4384", null ],
       [ "migrateTo", "class_ogre_1_1_bone_memory_manager.html#aeb86a46ec76b74740a6023b50a68b1d0", null ],
@@ -88,11 +63,10 @@ var group___memory =
       [ "nodeDestroyed", "class_ogre_1_1_bone_memory_manager.html#a4cb2f793c88a29af0521350d1f7a938d", null ],
       [ "nodeDettached", "class_ogre_1_1_bone_memory_manager.html#abb89ee21730dd39c59afc61fac4e48e1", null ],
       [ "nodeMoved", "class_ogre_1_1_bone_memory_manager.html#a65635569c31975d7d06ec76cc334f69a", null ],
-      [ "performCleanup", "class_ogre_1_1_bone_memory_manager.html#abc11663d0fb8952c7b9d575fb764d3fd", null ],
+      [ "performCleanup", "class_ogre_1_1_bone_memory_manager.html#a5ffc6b33d1a50b4d57a03b474139e518", null ],
       [ "setBoneRebaseListener", "class_ogre_1_1_bone_memory_manager.html#a530c24952c58a0547716da1a6b75d78b", null ]
     ] ],
     [ "Ogre::NodeArrayMemoryManager", "class_ogre_1_1_node_array_memory_manager.html", [
-      [ "PtrdiffVec", "class_ogre_1_1_node_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426", null ],
       [ "MemoryTypes", "class_ogre_1_1_node_array_memory_manager.html#af49bbc12dc3106a2fc7b8f1761ac9f5f", [
         [ "Parent", "class_ogre_1_1_node_array_memory_manager.html#af49bbc12dc3106a2fc7b8f1761ac9f5fa8c8ec6390a866bd1f9a26254c3e389f3", null ],
         [ "Owner", "class_ogre_1_1_node_array_memory_manager.html#af49bbc12dc3106a2fc7b8f1761ac9f5faf719d71db838dd7d4d921ee72c3f3ac0", null ],
@@ -109,30 +83,20 @@ var group___memory =
       ] ],
       [ "NodeArrayMemoryManager", "class_ogre_1_1_node_array_memory_manager.html#aa151e8893d1202165995ba9446ac1813", null ],
       [ "createNewNode", "class_ogre_1_1_node_array_memory_manager.html#ac6fb4f1d86cd6a094d2705d59560840d", null ],
-      [ "defragment", "class_ogre_1_1_node_array_memory_manager.html#a81ef5397bd517180f3f0e88f9a78633f", null ],
-      [ "destroy", "class_ogre_1_1_node_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0", null ],
       [ "destroyNode", "class_ogre_1_1_node_array_memory_manager.html#ad6a69c60fa0af29d3f36469bc68a3518", null ],
-      [ "getAllMemory", "class_ogre_1_1_node_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341", null ],
       [ "getFirstNode", "class_ogre_1_1_node_array_memory_manager.html#a7f8202c2ad3fd5e39ff357a1e4d4d013", null ],
-      [ "getFreeMemory", "class_ogre_1_1_node_array_memory_manager.html#ac639db8f3c078fa02ceb2691d4b86065", null ],
-      [ "getNumUsedSlotsIncludingFragmented", "class_ogre_1_1_node_array_memory_manager.html#afd91cd460057cd3a143e84c887655c26", null ],
-      [ "getUsedMemory", "class_ogre_1_1_node_array_memory_manager.html#a1483bb4f495abd37502c209eecc08881", null ],
-      [ "getWastedMemory", "class_ogre_1_1_node_array_memory_manager.html#a42fe5a861ebd6b4610189ce2be86b032", null ],
-      [ "initialize", "class_ogre_1_1_node_array_memory_manager.html#ad680fce37ec7058f94a5a69be2e2f4c5", null ],
-      [ "shrinkToFit", "class_ogre_1_1_node_array_memory_manager.html#a73d117284527cab40571e73e22f05f0f", null ],
       [ "ElementsMemSize", "class_ogre_1_1_node_array_memory_manager.html#a17a9a4ed2086a696252860e4dd1363a7", null ],
-      [ "MAX_MEMORY_SLOTS", "class_ogre_1_1_node_array_memory_manager.html#a738870646404c47464027863b9dea16c", null ],
       [ "NodeCleanupRoutines", "class_ogre_1_1_node_array_memory_manager.html#ae4768b67e11274e71bd9e63d967b9f6e", null ],
       [ "NodeInitRoutines", "class_ogre_1_1_node_array_memory_manager.html#a6c467643bfc4d843669d49d9a0a3fd8b", null ]
     ] ],
     [ "Ogre::NodeMemoryManager", "class_ogre_1_1_node_memory_manager.html", [
       [ "NodeMemoryManager", "class_ogre_1_1_node_memory_manager.html#a9e9d52de89e6efa2e55b5f61cb294452", null ],
       [ "~NodeMemoryManager", "class_ogre_1_1_node_memory_manager.html#ac9c59bce25d96c7768bf3629e6f1ed30", null ],
-      [ "_getDummyNode", "class_ogre_1_1_node_memory_manager.html#a2159d1fa8dd6e9a6b85d19cb67693785", null ],
+      [ "_getDummyNode", "class_ogre_1_1_node_memory_manager.html#a412053cae8c86607e82a4e8eb028b194", null ],
       [ "_setTwin", "class_ogre_1_1_node_memory_manager.html#a57055b26b6143047324615ab6bd3dae5", null ],
-      [ "applyRebase", "class_ogre_1_1_node_memory_manager.html#a26f857eb9a9d9a6dc9219e6bc3286d81", null ],
-      [ "buildDiffList", "class_ogre_1_1_node_memory_manager.html#af744a89c4b441d790945cd5bf36691b0", null ],
-      [ "defragment", "class_ogre_1_1_node_memory_manager.html#a950dffdcf577432988a0383405c25365", null ],
+      [ "applyRebase", "class_ogre_1_1_node_memory_manager.html#aa20a53d831e60d71b68aee7943193b37", null ],
+      [ "buildDiffList", "class_ogre_1_1_node_memory_manager.html#a20b94d34a5d7adca205bac9e4adecd9e", null ],
+      [ "defragment", "class_ogre_1_1_node_memory_manager.html#ae8a5414ed854ed4f3d3b7d55b2e068d1", null ],
       [ "getFirstNode", "class_ogre_1_1_node_memory_manager.html#afdfc8edff9c1cdee4a3a0aa87386a737", null ],
       [ "getMemoryManagerType", "class_ogre_1_1_node_memory_manager.html#a553b5879adf0c61bd251deeba8500ff9", null ],
       [ "getNumDepths", "class_ogre_1_1_node_memory_manager.html#a08a80e0d43c9243fd3f0541e84d95c02", null ],
@@ -141,16 +105,16 @@ var group___memory =
       [ "migrateTo", "class_ogre_1_1_node_memory_manager.html#a5e020556390ffe4f5402d3600211389d", null ],
       [ "migrateToAndAttach", "class_ogre_1_1_node_memory_manager.html#a4829385f3716fde5e5d535d47f9b4880", null ],
       [ "migrateToAndDetach", "class_ogre_1_1_node_memory_manager.html#a31406dd057c91b4679a3e00176f8f9c9", null ],
+      [ "neverDefragment", "class_ogre_1_1_node_memory_manager.html#a27c1a8cd68e6276e07c8806e5248b65b", null ],
       [ "nodeAttached", "class_ogre_1_1_node_memory_manager.html#a246cf28ff463b0233b066c8e2e23d592", null ],
       [ "nodeCreated", "class_ogre_1_1_node_memory_manager.html#a9decd63264c545614941e112519e2f28", null ],
       [ "nodeDestroyed", "class_ogre_1_1_node_memory_manager.html#ab55ba5e4a967cdf32b9de5e062d26582", null ],
       [ "nodeDettached", "class_ogre_1_1_node_memory_manager.html#ae2c25fec55b41ebf48d30617d2fb1102", null ],
       [ "nodeMoved", "class_ogre_1_1_node_memory_manager.html#aac63416f2b447710543c3b4a10d1766e", null ],
-      [ "performCleanup", "class_ogre_1_1_node_memory_manager.html#ac93aa2be3aea6ffb668ea69bc0297fb4", null ],
-      [ "shrinkToFit", "class_ogre_1_1_node_memory_manager.html#a4daf838c5f9969d53c7ebbf0a8dc38fc", null ]
+      [ "performCleanup", "class_ogre_1_1_node_memory_manager.html#a7ceae32e071b4ee2433e8463504ed398", null ],
+      [ "shrinkToFit", "class_ogre_1_1_node_memory_manager.html#adb199d18bd2c249d44fc89c2dbfdedaf", null ]
     ] ],
     [ "Ogre::ObjectDataArrayMemoryManager", "class_ogre_1_1_object_data_array_memory_manager.html", [
-      [ "PtrdiffVec", "class_ogre_1_1_object_data_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426", null ],
       [ "MemoryTypes", "class_ogre_1_1_object_data_array_memory_manager.html#a01818bd20c4b78825933f9b4e5c83735", [
         [ "Parent", "class_ogre_1_1_object_data_array_memory_manager.html#a01818bd20c4b78825933f9b4e5c83735ac64922a0801701b751899aff96fa1072", null ],
         [ "Owner", "class_ogre_1_1_object_data_array_memory_manager.html#a01818bd20c4b78825933f9b4e5c83735a32327967a22f45457ddf494bb4fe88e9", null ],
@@ -168,19 +132,9 @@ var group___memory =
       ] ],
       [ "ObjectDataArrayMemoryManager", "class_ogre_1_1_object_data_array_memory_manager.html#ad2af8c192791b036134a6bf332972ce8", null ],
       [ "createNewNode", "class_ogre_1_1_object_data_array_memory_manager.html#aefcf632ca4631c7dcff0adf2d0e3328f", null ],
-      [ "defragment", "class_ogre_1_1_object_data_array_memory_manager.html#a81ef5397bd517180f3f0e88f9a78633f", null ],
-      [ "destroy", "class_ogre_1_1_object_data_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0", null ],
       [ "destroyNode", "class_ogre_1_1_object_data_array_memory_manager.html#abfa9d99a622bd7428e2458c554bb2808", null ],
-      [ "getAllMemory", "class_ogre_1_1_object_data_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341", null ],
       [ "getFirstNode", "class_ogre_1_1_object_data_array_memory_manager.html#af6ef4eb0a0cba2e9fb5cdc8a61d30fa3", null ],
-      [ "getFreeMemory", "class_ogre_1_1_object_data_array_memory_manager.html#ac639db8f3c078fa02ceb2691d4b86065", null ],
-      [ "getNumUsedSlotsIncludingFragmented", "class_ogre_1_1_object_data_array_memory_manager.html#afd91cd460057cd3a143e84c887655c26", null ],
-      [ "getUsedMemory", "class_ogre_1_1_object_data_array_memory_manager.html#a1483bb4f495abd37502c209eecc08881", null ],
-      [ "getWastedMemory", "class_ogre_1_1_object_data_array_memory_manager.html#a42fe5a861ebd6b4610189ce2be86b032", null ],
-      [ "initialize", "class_ogre_1_1_object_data_array_memory_manager.html#ad680fce37ec7058f94a5a69be2e2f4c5", null ],
-      [ "shrinkToFit", "class_ogre_1_1_object_data_array_memory_manager.html#a73d117284527cab40571e73e22f05f0f", null ],
       [ "ElementsMemSize", "class_ogre_1_1_object_data_array_memory_manager.html#a0a0ae39e5ad5949c8ceb27f82db9a76a", null ],
-      [ "MAX_MEMORY_SLOTS", "class_ogre_1_1_object_data_array_memory_manager.html#a738870646404c47464027863b9dea16c", null ],
       [ "ObjCleanupRoutines", "class_ogre_1_1_object_data_array_memory_manager.html#a3669ef2901676e46a8d2961761e8660c", null ]
     ] ],
     [ "Ogre::ObjectMemoryManager", "class_ogre_1_1_object_memory_manager.html", [
@@ -189,10 +143,10 @@ var group___memory =
       [ "_getDummyNode", "class_ogre_1_1_object_memory_manager.html#ae1c8bb313d67c58eb8405040b77ad567", null ],
       [ "_getTotalRenderQueues", "class_ogre_1_1_object_memory_manager.html#ad6c0d3a0c920dd3890e2606b4bc8627b", null ],
       [ "_setTwin", "class_ogre_1_1_object_memory_manager.html#ada9ae13f4b0cc10d7dee8e8d15a02313", null ],
-      [ "applyRebase", "class_ogre_1_1_object_memory_manager.html#a0b745fa9ad3f3b67e99ad691338b6bac", null ],
-      [ "buildDiffList", "class_ogre_1_1_object_memory_manager.html#aa1d94b69514c23e720a686ad7e9750b7", null ],
+      [ "applyRebase", "class_ogre_1_1_object_memory_manager.html#ae08ed3ab4ea707b14f9ddeff2296e54b", null ],
+      [ "buildDiffList", "class_ogre_1_1_object_memory_manager.html#a5ef5eb570db358e45e9e9a7969e14788", null ],
       [ "calculateTotalNumObjectDataIncludingFragmentedSlots", "class_ogre_1_1_object_memory_manager.html#a346cede27716fbf7136b1ca934532e65", null ],
-      [ "defragment", "class_ogre_1_1_object_memory_manager.html#a50ca7dc577c00125e64d616332ad10a2", null ],
+      [ "defragment", "class_ogre_1_1_object_memory_manager.html#a4d5bcff087383d2a8e57a953b9d6d66a", null ],
       [ "getFirstObjectData", "class_ogre_1_1_object_memory_manager.html#a5a3205860c2fded5b34bb8f0802526af", null ],
       [ "getMemoryManagerType", "class_ogre_1_1_object_memory_manager.html#a032c23b281a75f46db6eeda9f6827b3d", null ],
       [ "getNumRenderQueues", "class_ogre_1_1_object_memory_manager.html#aacc3f26a856c2e4f9b463d3fed7825f4", null ],
@@ -202,8 +156,8 @@ var group___memory =
       [ "objectCreated", "class_ogre_1_1_object_memory_manager.html#a30c9f2fecf984b7045f656517b931849", null ],
       [ "objectDestroyed", "class_ogre_1_1_object_memory_manager.html#aae2e6b8ba5fbcabd6765f23e4d228e36", null ],
       [ "objectMoved", "class_ogre_1_1_object_memory_manager.html#a3ba0525c6ea5c99223df05d5593822ac", null ],
-      [ "performCleanup", "class_ogre_1_1_object_memory_manager.html#aa19abbe93c68d689153baa39041841b0", null ],
-      [ "shrinkToFit", "class_ogre_1_1_object_memory_manager.html#a726aa96878859ecc3ca9837c88073933", null ]
+      [ "performCleanup", "class_ogre_1_1_object_memory_manager.html#a6a9f7f049d953a3fb4fe4ae5bc2ce225", null ],
+      [ "shrinkToFit", "class_ogre_1_1_object_memory_manager.html#a653f6a2a1b0deba78eb242e9d09538ef", null ]
     ] ],
     [ "Ogre::STLAllocator< T, AllocPolicy >", "class_ogre_1_1_s_t_l_allocator.html", [
       [ "rebind", "struct_ogre_1_1_s_t_l_allocator_1_1rebind.html", [
@@ -225,41 +179,18 @@ var group___memory =
       [ "address", "class_ogre_1_1_s_t_l_allocator.html#abbf348ef209c5e0e1f00ca1a8645c969", null ],
       [ "address", "class_ogre_1_1_s_t_l_allocator.html#a6612f5f0613e94729e714bda4b8bec93", null ],
       [ "allocate", "class_ogre_1_1_s_t_l_allocator.html#a219db3b3227be55452bf297cdb7bea89", null ],
-      [ "construct", "class_ogre_1_1_s_t_l_allocator.html#a04d59556081dfe8d64d660b336b6fc28", null ],
       [ "construct", "class_ogre_1_1_s_t_l_allocator.html#ad6ebf2ce6e910595ef613fc955e6df10", null ],
       [ "deallocate", "class_ogre_1_1_s_t_l_allocator.html#afc5b83dfdc2263f0c6dbebe62c4681a9", null ],
       [ "destroy", "class_ogre_1_1_s_t_l_allocator.html#ad4101ccdcdc6c5336a2ebd5169c55ff9", null ],
-      [ "max_size", "class_ogre_1_1_s_t_l_allocator.html#a7162d2ac5666953fb4bfd2472ccf4764", null ]
+      [ "max_size", "class_ogre_1_1_s_t_l_allocator.html#a9c1e83043b7125ab226ddc78150520c8", null ]
     ] ],
     [ "Ogre::STLAllocatorBase< T >", "struct_ogre_1_1_s_t_l_allocator_base.html", [
       [ "value_type", "struct_ogre_1_1_s_t_l_allocator_base.html#a3fc45e6ad404fa54ad9246682e7ccd88", null ]
     ] ],
     [ "Ogre::STLAllocatorBase< const T >", "struct_ogre_1_1_s_t_l_allocator_base_3_01const_01_t_01_4.html", [
+      [ "value_type", "struct_ogre_1_1_s_t_l_allocator_base.html#a3fc45e6ad404fa54ad9246682e7ccd88", null ],
       [ "value_type", "struct_ogre_1_1_s_t_l_allocator_base_3_01const_01_t_01_4.html#ad0004d963c1616f06b527bc144bd883f", null ]
     ] ],
-    [ "OGRE_ALLOC_T", "group___memory.html#ga3211e4a6a806aa789b38dce2432ef472", null ],
-    [ "OGRE_ALLOC_T_ALIGN", "group___memory.html#gafc79c14937612b02ac50631c08666b26", null ],
-    [ "OGRE_ALLOC_T_SIMD", "group___memory.html#ga728b719dd1425d46a78fe87d6f9ea6a5", null ],
-    [ "OGRE_DELETE", "group___memory.html#gad18eff671a00617b21c8e35a7f545690", null ],
-    [ "OGRE_DELETE_ARRAY_T", "group___memory.html#gab9f9fa14d424036dc5881cbcb3c741e0", null ],
-    [ "OGRE_DELETE_ARRAY_T_ALIGN", "group___memory.html#ga25e1e9ce907fc367cc735465c940da23", null ],
-    [ "OGRE_DELETE_ARRAY_T_SIMD", "group___memory.html#ga3ceedc1e74432821ffab664232c12d04", null ],
-    [ "OGRE_DELETE_T", "group___memory.html#ga0b0974da65362dd8a14071e7f6e4daca", null ],
-    [ "OGRE_DELETE_T_ALIGN", "group___memory.html#ga076af127ea8efe2284e03ab4c2057603", null ],
-    [ "OGRE_DELETE_T_SIMD", "group___memory.html#ga1a5d598e538371f2fca9608277051347", null ],
-    [ "OGRE_FREE", "group___memory.html#gacfd8dc937cf390c7bff05495f0dc10cf", null ],
-    [ "OGRE_FREE_ALIGN", "group___memory.html#gaa06d37a211e3da357b8457ccdb4decac", null ],
-    [ "OGRE_FREE_SIMD", "group___memory.html#gaf7501eb098fc6671420c628dc80af2a8", null ],
-    [ "OGRE_MALLOC", "group___memory.html#ga2382b731c3d757f74f0fedf2b14ed9d6", null ],
-    [ "OGRE_MALLOC_ALIGN", "group___memory.html#ga876cf0a4c7e209ce798b5e6708ca2343", null ],
-    [ "OGRE_MALLOC_SIMD", "group___memory.html#gafd7ddaef10ac9ea1ffbd18902167b9a2", null ],
-    [ "OGRE_NEW", "group___memory.html#gab5fc1358fd5a889de0a06d07e45df1ff", null ],
-    [ "OGRE_NEW_ARRAY_T", "group___memory.html#ga6c428bbdad197df6a4ba22d3c1d48f5a", null ],
-    [ "OGRE_NEW_ARRAY_T_ALIGN", "group___memory.html#ga51224b5c8af6fd85e192975ebe20139b", null ],
-    [ "OGRE_NEW_ARRAY_T_SIMD", "group___memory.html#gaa55846bae98cf66fd5158ad0d4d623bb", null ],
-    [ "OGRE_NEW_T", "group___memory.html#ga46253f12658ce0922e982a8a9dd11312", null ],
-    [ "OGRE_NEW_T_ALIGN", "group___memory.html#ga4c928813aac2c96ae5cc775aacd3e26d", null ],
-    [ "OGRE_NEW_T_SIMD", "group___memory.html#ga2f7eef98b7fe3ba9f36630b787d603b1", null ],
     [ "Ogre::CleanupRoutines", "group___memory.html#ga4670b4da69fc17f183690626fd3bf47f", null ],
     [ "Ogre::MemoryCategory", "group___memory.html#ga830fab51be174d6f2849857cb1abb36a", [
       [ "Ogre::MEMCATEGORY_GENERAL", "group___memory.html#gga830fab51be174d6f2849857cb1abb36aa8ac29a2852b1b5fe79d1659b16f521cb", null ],
