@@ -2,29 +2,14 @@ var group___optional =
 [
     [ "Paging", "group___paging.html", "group___paging" ],
     [ "Property", "group___property.html", "group___property" ],
-    [ "Terrain", "group___terrain.html", "group___terrain" ],
     [ "OgrePageFileFormats.h", "_ogre_page_file_formats_8h.html", null ],
     [ "Ogre::Grid3DPageStrategy", "class_ogre_1_1_grid3_d_page_strategy.html", [
       [ "Grid3DPageStrategy", "group___optional.html#gae6874dc60fa86f45dc04e28f69685833", null ],
       [ "~Grid3DPageStrategy", "group___optional.html#ga5f68c64e312d28a0915303f75fa9e442", null ],
       [ "createData", "group___optional.html#ga8a092ef6651d497c1c431f1f21419d9b", null ],
       [ "destroyData", "group___optional.html#gac15aee85717bf206333658917836bfd0", null ],
-      [ "frameEnd", "class_ogre_1_1_grid3_d_page_strategy.html#ga1990d8b1110ac0555e3ec18da77675b8", null ],
-      [ "frameStart", "class_ogre_1_1_grid3_d_page_strategy.html#gadb6fc9f82a8ea955971b46c052a151af", null ],
-      [ "getManager", "class_ogre_1_1_grid3_d_page_strategy.html#ga31e7d84bd56cb046b7503b121c6fef9a", null ],
-      [ "getName", "class_ogre_1_1_grid3_d_page_strategy.html#gaf8f2e117153ce9e6c4899552ee7f7ec4", null ],
       [ "getPageID", "group___optional.html#ga31cb931801f78214a25733df20ad10fc", null ],
       [ "notifyCamera", "group___optional.html#ga93731f5971fba009a64bc4e4d8ce8517", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_grid3_d_page_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_grid3_d_page_strategy.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_grid3_d_page_strategy.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_grid3_d_page_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "updateDebugDisplay", "group___optional.html#ga32e80bd39ff8f3d9b9a35d5f2d1f0751", null ]
     ] ],
     [ "Ogre::Grid3DPageStrategyData", "class_ogre_1_1_grid3_d_page_strategy_data.html", [
@@ -47,16 +32,6 @@ var group___optional =
       [ "getMidPointGridSpace", "group___optional.html#ga2762e5a38c2a8f887236920efb6dc840", null ],
       [ "getOrigin", "group___optional.html#ga84be79828f3f8cdcabfb6886d0262cf6", null ],
       [ "load", "group___optional.html#gab5159dd7922b777ed101992b5319b20b", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy_data.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy_data.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_grid3_d_page_strategy_data.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_grid3_d_page_strategy_data.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_grid3_d_page_strategy_data.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy_data.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy_data.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_grid3_d_page_strategy_data.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_grid3_d_page_strategy_data.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_grid3_d_page_strategy_data.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "save", "group___optional.html#gaedcf87a66b42befb2aba22b6d42fee58", null ],
       [ "setCellRange", "group___optional.html#gaa2df60347efc29d35a690e71c64531eb", null ],
       [ "setCellRangeMaxX", "group___optional.html#gaec607907c425472cc2edaab54c7a0d90", null ],
@@ -83,66 +58,29 @@ var group___optional =
       [ "getName", "group___optional.html#gaf8f2e117153ce9e6c4899552ee7f7ec4", null ],
       [ "getPageID", "group___optional.html#ga78f9813d951ab38b1ebbae6b0f807df6", null ],
       [ "notifyCamera", "group___optional.html#gaa3db993f4446cb811e094c8ad0ab23df", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_page_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_page_strategy.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_page_strategy.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_page_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "updateDebugDisplay", "group___optional.html#ga96e254ffc49131053601b8f17e4054f8", null ]
     ] ],
     [ "Ogre::PageStrategyData", "class_ogre_1_1_page_strategy_data.html", [
       [ "PageStrategyData", "group___optional.html#gaee0c7372a5df6ba16cb608bb4634b43a", null ],
       [ "~PageStrategyData", "group___optional.html#ga5866f1cb60842627008c050dc0afdc63", null ],
       [ "load", "group___optional.html#gaab80a3280ea2b5526ecb2a8652716533", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy_data.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy_data.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_page_strategy_data.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_page_strategy_data.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_page_strategy_data.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy_data.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy_data.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_page_strategy_data.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_page_strategy_data.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_page_strategy_data.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "save", "group___optional.html#gae7b43543191e014b5df371be2626b164", null ]
     ] ],
     [ "Ogre::SimplePageContentCollection", "class_ogre_1_1_simple_page_content_collection.html", [
       [ "ContentList", "group___optional.html#gab2bba46c537debed82c678c066257a46", null ],
       [ "SimplePageContentCollection", "group___optional.html#gaf7c7c261d679b97e76e29ead8be3bd17", null ],
       [ "~SimplePageContentCollection", "group___optional.html#ga72fc689a31a6df0a2f647e8fd015ffba", null ],
-      [ "_notifyAttached", "class_ogre_1_1_simple_page_content_collection.html#a774c75c12ecd87171424be83226d6c45", null ],
       [ "createContent", "group___optional.html#ga50a39e2aebde86baec57f3372cf4830f", null ],
       [ "destroyContent", "group___optional.html#ga184464de7cd9ea739d91364e3e182a8a", null ],
       [ "frameEnd", "group___optional.html#gaf8abde8b5410ca7c9b6fb23fea700dc5", null ],
       [ "frameStart", "group___optional.html#gaf009a28d63fdea54a4a495ca94103dbd", null ],
       [ "getContentList", "group___optional.html#gae2264dc15d053064174a7cceab6014ad", null ],
-      [ "getManager", "class_ogre_1_1_simple_page_content_collection.html#aa9af098e982558beb074029682573bc8", null ],
-      [ "getParentPage", "class_ogre_1_1_simple_page_content_collection.html#a0504c71e568a3d3945bc8d984402ea42", null ],
-      [ "getSceneManager", "class_ogre_1_1_simple_page_content_collection.html#a2f8f2b99a8cef0759559fa5423949e3d", null ],
-      [ "getType", "class_ogre_1_1_simple_page_content_collection.html#ad7d7937eac01bfcdce18028b8851ec1d", null ],
       [ "load", "group___optional.html#ga990fe2d86d3e7b18f637b0c41de794f2", null ],
       [ "notifyCamera", "group___optional.html#ga46e7142f461ad0c2a18d7f2731c27375", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_simple_page_content_collection.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_simple_page_content_collection.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_simple_page_content_collection.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_simple_page_content_collection.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "prepare", "group___optional.html#gaec07cbbc6bbb28c3bb8c6e97c79b49eb", null ],
       [ "save", "group___optional.html#ga3b44d9133028051fa8310fdf73087e16", null ],
       [ "unload", "group___optional.html#ga10ee90b66dc24b7df217aa4d599dd112", null ],
       [ "unprepare", "group___optional.html#ga309e0261c394877563fadfe7dc88a971", null ],
-      [ "CHUNK_ID", "class_ogre_1_1_simple_page_content_collection.html#aa73e82a2444f6105c6e61ef83d18292d", null ],
-      [ "CHUNK_VERSION", "class_ogre_1_1_simple_page_content_collection.html#a25aebf4e31d562701d2c7640e1056121", null ],
       [ "SUBCLASS_CHUNK_ID", "group___optional.html#ga83a7da85aebcb68a7d0042ac11391d3b", null ],
       [ "SUBCLASS_CHUNK_VERSION", "group___optional.html#gacec3e8d6e9439e811e76a3ed1584f1f7", null ]
     ] ],
@@ -152,16 +90,6 @@ var group___optional =
       [ "createInstance", "group___optional.html#ga279734c21b7367b45aafa471c249e67a", null ],
       [ "destroyInstance", "group___optional.html#ga1d05d1e51b58261f5f2e2cfa23980408", null ],
       [ "getName", "group___optional.html#ga59156cddb7267fb162f8d9ec3e006df8", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection_factory.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection_factory.html#acb46d4b0a597156d9ba5abc39d127792", null ],
-      [ "operator delete", "class_ogre_1_1_simple_page_content_collection_factory.html#a1c727e879a260c37b00ce5505fe8e144", null ],
-      [ "operator delete[]", "class_ogre_1_1_simple_page_content_collection_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
-      [ "operator delete[]", "class_ogre_1_1_simple_page_content_collection_factory.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection_factory.html#ab422c67a2c8844f410fe822a357cba3b", null ],
-      [ "operator new", "class_ogre_1_1_simple_page_content_collection_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
-      [ "operator new[]", "class_ogre_1_1_simple_page_content_collection_factory.html#adce32528577d71b228692df906ecd17c", null ],
-      [ "operator new[]", "class_ogre_1_1_simple_page_content_collection_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
       [ "FACTORY_NAME", "group___optional.html#ga285aec0d6c6f714d3f07a72e32a152e0", null ]
     ] ],
     [ "Ogre::SimplePageContentCollection::ContentList", "group___optional.html#gab2bba46c537debed82c678c066257a46", null ],
@@ -188,10 +116,10 @@ var group___optional =
     [ "Ogre::PageStrategy::destroyData", "group___optional.html#ga90dd9281a8804b6332a6fa477a950186", null ],
     [ "Ogre::SimplePageContentCollectionFactory::destroyInstance", "group___optional.html#ga1d05d1e51b58261f5f2e2cfa23980408", null ],
     [ "Ogre::Grid3DPageStrategyData::determineGridLocation", "group___optional.html#gabb6b2b57c3c42596d13206727bb66d97", null ],
-    [ "Ogre::SimplePageContentCollection::frameEnd", "group___optional.html#gaf8abde8b5410ca7c9b6fb23fea700dc5", null ],
     [ "Ogre::PageStrategy::frameEnd", "group___optional.html#ga1990d8b1110ac0555e3ec18da77675b8", null ],
-    [ "Ogre::SimplePageContentCollection::frameStart", "group___optional.html#gaf009a28d63fdea54a4a495ca94103dbd", null ],
+    [ "Ogre::SimplePageContentCollection::frameEnd", "group___optional.html#gaf8abde8b5410ca7c9b6fb23fea700dc5", null ],
     [ "Ogre::PageStrategy::frameStart", "group___optional.html#gadb6fc9f82a8ea955971b46c052a151af", null ],
+    [ "Ogre::SimplePageContentCollection::frameStart", "group___optional.html#gaf009a28d63fdea54a4a495ca94103dbd", null ],
     [ "Ogre::Grid3DPageStrategyData::getBottomLeftGridSpace", "group___optional.html#gacea5d8841152d6a18090adb007fd3c81", null ],
     [ "Ogre::Grid3DPageStrategyData::getCellRangeMaxX", "group___optional.html#ga0df4533060e2b0a3bc640ca64ab3aa38", null ],
     [ "Ogre::Grid3DPageStrategyData::getCellRangeMaxY", "group___optional.html#gab9d99aae2e1fe0ece791fa139faf800b", null ],
@@ -211,16 +139,16 @@ var group___optional =
     [ "Ogre::Grid3DPageStrategyData::getOrigin", "group___optional.html#ga84be79828f3f8cdcabfb6886d0262cf6", null ],
     [ "Ogre::Grid3DPageStrategy::getPageID", "group___optional.html#ga31cb931801f78214a25733df20ad10fc", null ],
     [ "Ogre::PageStrategy::getPageID", "group___optional.html#ga78f9813d951ab38b1ebbae6b0f807df6", null ],
-    [ "Ogre::SimplePageContentCollection::load", "group___optional.html#ga990fe2d86d3e7b18f637b0c41de794f2", null ],
     [ "Ogre::Grid3DPageStrategyData::load", "group___optional.html#gab5159dd7922b777ed101992b5319b20b", null ],
     [ "Ogre::PageStrategyData::load", "group___optional.html#gaab80a3280ea2b5526ecb2a8652716533", null ],
-    [ "Ogre::SimplePageContentCollection::notifyCamera", "group___optional.html#ga46e7142f461ad0c2a18d7f2731c27375", null ],
+    [ "Ogre::SimplePageContentCollection::load", "group___optional.html#ga990fe2d86d3e7b18f637b0c41de794f2", null ],
     [ "Ogre::Grid3DPageStrategy::notifyCamera", "group___optional.html#ga93731f5971fba009a64bc4e4d8ce8517", null ],
     [ "Ogre::PageStrategy::notifyCamera", "group___optional.html#gaa3db993f4446cb811e094c8ad0ab23df", null ],
+    [ "Ogre::SimplePageContentCollection::notifyCamera", "group___optional.html#ga46e7142f461ad0c2a18d7f2731c27375", null ],
     [ "Ogre::SimplePageContentCollection::prepare", "group___optional.html#gaec07cbbc6bbb28c3bb8c6e97c79b49eb", null ],
     [ "Ogre::Grid3DPageStrategyData::save", "group___optional.html#gaedcf87a66b42befb2aba22b6d42fee58", null ],
-    [ "Ogre::SimplePageContentCollection::save", "group___optional.html#ga3b44d9133028051fa8310fdf73087e16", null ],
     [ "Ogre::PageStrategyData::save", "group___optional.html#gae7b43543191e014b5df371be2626b164", null ],
+    [ "Ogre::SimplePageContentCollection::save", "group___optional.html#ga3b44d9133028051fa8310fdf73087e16", null ],
     [ "Ogre::Grid3DPageStrategyData::setCellRange", "group___optional.html#gaa2df60347efc29d35a690e71c64531eb", null ],
     [ "Ogre::Grid3DPageStrategyData::setCellRangeMaxX", "group___optional.html#gaec607907c425472cc2edaab54c7a0d90", null ],
     [ "Ogre::Grid3DPageStrategyData::setCellRangeMaxY", "group___optional.html#ga03ed092d36316567075ad898eff18ebd", null ],
