@@ -148,27 +148,27 @@ var manual =
         [ "Execution mask", "compositor.html#CompositorWorkspacesStereoExecutionMask", null ],
         [ "Default values", "compositor.html#CompositorWorkspacesStereoDefaultValues", null ]
       ] ],
-      [ "Advanced MSAA", "compositor.html#autotoc_md76", [
-        [ "What is MSAA?", "compositor.html#autotoc_md77", [
-          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md78", null ],
-          [ "MSAA approach to the problem", "compositor.html#autotoc_md79", null ]
+      [ "Advanced MSAA", "compositor.html#autotoc_md95", [
+        [ "What is MSAA?", "compositor.html#autotoc_md96", [
+          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md97", null ],
+          [ "MSAA approach to the problem", "compositor.html#autotoc_md98", null ]
         ] ],
-        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md80", null ],
-        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md81", null ]
+        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md99", null ],
+        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md100", null ]
       ] ]
     ] ],
     [ "Global Illumination Methods", "_gi_methods.html", "_gi_methods" ],
     [ "Image Voxel Cone Tracing", "_image_voxel_cone_tracing.html", [
       [ "Step 1: Image Voxelizer", "_image_voxel_cone_tracing.html#IVCT_Step1", [
         [ "Downside", "_image_voxel_cone_tracing.html#IVCT_Step1_Downside", [
-          [ "Non-researched solutions:", "_image_voxel_cone_tracing.html#autotoc_md29", null ]
+          [ "Non-researched solutions:", "_image_voxel_cone_tracing.html#autotoc_md28", null ]
         ] ],
-        [ "Trivia", "_image_voxel_cone_tracing.html#autotoc_md30", null ]
+        [ "Trivia", "_image_voxel_cone_tracing.html#autotoc_md29", null ]
       ] ],
       [ "Step 2: Row Translation", "_image_voxel_cone_tracing.html#IVCT_Step2", null ],
       [ "Step 3: Cascades", "_image_voxel_cone_tracing.html#IVCT_Step3", null ],
-      [ "Wait isn't this what UE5's Lumen does?", "_image_voxel_cone_tracing.html#autotoc_md31", null ],
-      [ "Wait isn't this what Godot does?", "_image_voxel_cone_tracing.html#autotoc_md32", null ]
+      [ "Wait isn't this what UE5's Lumen does?", "_image_voxel_cone_tracing.html#autotoc_md30", null ],
+      [ "Wait isn't this what Godot does?", "_image_voxel_cone_tracing.html#autotoc_md31", null ]
     ] ],
     [ "Instancing", "instancing.html", [
       [ "What is instancing?", "instancing.html#WhatIsInstancing", null ],
@@ -194,74 +194,14 @@ var manual =
     ] ],
     [ "Threading", "threading.html", [
       [ "Initializing", "threading.html#ThreadingInitializing", [
-        [ "Ideal number of threads", "threading.html#ThreadingInitializingNumberOfThreads", null ],
-        [ "More info about InstancingThreadedCullingMethod", "threading.html#ThreadingInitializingCullingMethod", null ]
+        [ "Ideal number of threads", "threading.html#ThreadingInitializingNumberOfThreads", null ]
       ] ],
       [ "What tasks are threaded in Ogre", "threading.html#ThreadingInOgre", null ],
       [ "Using Ogre's threading system for custom tasks", "threading.html#ThreadingCustomTasks", null ],
       [ "Thread safety of SceneNodes", "threading.html#ThreadSafetySceneNodes", null ]
     ] ],
     [ "Performance Hints", "performance.html", null ],
-    [ "HLMS: High Level Material System", "hlms.html", [
-      [ "Fundamental changes", "hlms.html#HlmsChanges", [
-        [ "Viewports and Scissor tests", "hlms.html#HlmsChangesViewports", null ],
-        [ "A lot of data is stored in \"Blocks\"", "hlms.html#HlmsChangesBlocks", null ],
-        [ "Materials are still alive", "hlms.html#HlmsChangesMaterialsAlive", null ],
-        [ "Fixed Function has been removed", "hlms.html#HlmsChangesFFP", null ]
-      ] ],
-      [ "The three components", "hlms.html#HlmsComponents", null ],
-      [ "Blocks", "hlms.html#HlmsBlocks", [
-        [ "Datablocks", "hlms.html#HlmsBlocksDatablocks", null ],
-        [ "Macroblocks", "hlms.html#HlmsBlocksMacroblocks", null ],
-        [ "Blendblocks", "hlms.html#HlmsBlocksBlendblocks", null ],
-        [ "Samplerblocks", "hlms.html#HlmsBlocksSampleblocks", null ]
-      ] ],
-      [ "Hlms templates", "hlms.html#HlmsTemplates", null ],
-      [ "The Hlms preprocessor", "hlms.html#HlmsPreprocessor", [
-        [ "Preprocessor syntax", "hlms.html#HlmsPreprocessorSyntax", [
-          [ "@property( expression )", "hlms.html#HlmsPreprocessorSyntaxProperty", null ],
-          [ "@foreach( count, scopedVar, [start] )", "hlms.html#HlmsPreprocessorSyntaxForeach", null ],
-          [ "@counter( variable )", "hlms.html#HlmsPreprocessorSyntaxCounter", null ],
-          [ "@value( variable )", "hlms.html#HlmsPreprocessorSyntaxValue", null ],
-          [ "@set add sub mul div mod min max", "hlms.html#HlmsPreprocessorSyntaxSetEtc", null ],
-          [ "@piece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxPiece", null ],
-          [ "@insertpiece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxInsertpiece", null ],
-          [ "@undefpiece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxUndefpiece", null ],
-          [ "@pset padd psub pmul pdiv pmod pmin pmax", "hlms.html#HlmsPreprocessorSyntaxPsetEtc", null ]
-        ] ]
-      ] ],
-      [ "Creation of shaders", "hlms.html#HlmsCreationOfShaders", [
-        [ "C++ interaction with shader templates", "hlms.html#HlmsCreationOfShadersCpp", null ],
-        [ "Common conventions", "hlms.html#HlmsCreationOfShadersConventions", null ],
-        [ "Hot reloading", "hlms.html#HlmsCreationOfShadersHotReloading", null ],
-        [ "Disabling a stage", "hlms.html#HlmsCreationOfShadersDisablingStage", null ],
-        [ "Customizing an existing implementation", "hlms.html#HlmsCreationOfShadersCustomizing", null ]
-      ] ],
-      [ "Run-time rendering", "hlms.html#HlmsRuntimeRendering", [
-        [ "preparePassHash", "hlms.html#HlmsRuntimeRenderingPreparePassHash", null ],
-        [ "fillBuffersFor", "hlms.html#HlmsRuntimeRenderingFillBuffersFor", null ]
-      ] ],
-      [ "Using the HLMS implementations", "hlms.html#UsingHlmsImplementation", [
-        [ "Initialization", "hlms.html#UsingHlmsImplementationInitialization", null ],
-        [ "Deinitialization", "hlms.html#UsingHlmsImplementationDeinitilization", null ],
-        [ "Creating a datablock", "hlms.html#UsingHlmsImplementationCreatingDatablock", null ]
-      ] ],
-      [ "The Hlms Texture Manager", "hlms.html#HlmsTextureManager", [
-        [ "Automatic batching", "hlms.html#HlmsTextureManagerAutomaticBatching", [
-          [ "Texture types", "hlms.html#HlmsTextureManagerAutomaticBatchingTextureTypes", null ],
-          [ "Automatic parameters", "hlms.html#HlmsTextureManagerAutomaticBatchingAutoParams", null ],
-          [ "Loading a texture twice (i.e. with a different format) via aliasing", "hlms.html#HlmsTextureManagerAutomaticBatchingLoadingTwice", null ]
-        ] ],
-        [ "Manual: Texture packs", "hlms.html#HlmsTextureManagerTexturePacks", null ],
-        [ "Watching out for memory consumption", "hlms.html#HlmsTextureManagerWatchOutMemory", [
-          [ "Additional memory considerations", "hlms.html#HlmsTextureManagerWatchOutMemoryConsiderations", null ],
-          [ "setWorkerThreadMinimumBudget warning", "hlms.html#setWorkerThreadMinimumBudget", null ]
-        ] ]
-      ] ],
-      [ "Troubleshooting", "hlms.html#HlmsTroubleshooting", [
-        [ "My shadows don't show up or are very glitchy", "hlms.html#HlmsTroubleshootingShadow", null ]
-      ] ]
-    ] ],
+    [ "HLMS: High Level Material System", "hlms.html", "hlms" ],
     [ "AZDO changes (Aproaching Zero Driver Overhead)", "azdo.html", [
       [ "V2 and v1 objects", "azdo.html#V2AndV1Objects", [
         [ "Longevity of the v1 objects and deprecation", "azdo.html#V2AndV1ObjectsV1Longevity", null ]
@@ -278,73 +218,73 @@ var manual =
       [ "Post-processing the command buffer", "commandbuffer.html#CommandBufferPostProcessing", null ]
     ] ],
     [ "Terra System", "_terra_system.html", [
-      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md67", null ],
-      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md68", null ],
-      [ "Terra cells", "_terra_system.html#autotoc_md69", [
-        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md70", null ],
-        [ "Outer layers", "_terra_system.html#autotoc_md71", null ]
+      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md86", null ],
+      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md87", null ],
+      [ "Terra cells", "_terra_system.html#autotoc_md88", [
+        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md89", null ],
+        [ "Outer layers", "_terra_system.html#autotoc_md90", null ]
       ] ],
-      [ "Skirts", "_terra_system.html#autotoc_md72", null ],
-      [ "Shadows", "_terra_system.html#autotoc_md73", null ],
-      [ "Shading", "_terra_system.html#autotoc_md74", null ],
-      [ "Why is it not a component?", "_terra_system.html#autotoc_md75", null ]
+      [ "Skirts", "_terra_system.html#autotoc_md91", null ],
+      [ "Shadows", "_terra_system.html#autotoc_md92", null ],
+      [ "Shading", "_terra_system.html#autotoc_md93", null ],
+      [ "Why is it not a component?", "_terra_system.html#autotoc_md94", null ]
     ] ],
     [ "Tunning memory consumption and resources", "_tuning_memory_resources.html", [
       [ "Grouping textures by type", "_tuning_memory_resources.html#GroupingTexturesByType", null ],
       [ "Dynamic vs Default buffers", "_tuning_memory_resources.html#DynamicVsDefaultBuffers", null ],
       [ "Tweaking default memory consumption by VaoManager", "_tuning_memory_resources.html#TweakingVaoManager", [
-        [ "Vulkan and TEXTURES_OPTIMAL", "_tuning_memory_resources.html#autotoc_md33", null ]
+        [ "Vulkan and TEXTURES_OPTIMAL", "_tuning_memory_resources.html#autotoc_md32", null ]
       ] ]
     ] ],
     [ "What's new in Ogre 2.2", "_ogre22_changes.html", [
-      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md34", [
-        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md35", null ]
+      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md33", [
+        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md34", null ]
       ] ],
-      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md36", null ],
-      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md37", [
-        [ "PixelFormats", "_ogre22_changes.html#autotoc_md38", [
-          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md39", null ]
+      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md35", null ],
+      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md36", [
+        [ "PixelFormats", "_ogre22_changes.html#autotoc_md37", [
+          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md38", null ]
         ] ],
-        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md40", [
-          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md41", null ],
-          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md42", null ],
-          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md43", null ],
-          [ "Upload streaming", "_ogre22_changes.html#autotoc_md44", null ],
-          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md45", null ],
-          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md46", null ]
+        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md39", [
+          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md40", null ],
+          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md41", null ],
+          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md42", null ],
+          [ "Upload streaming", "_ogre22_changes.html#autotoc_md43", null ],
+          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md44", null ],
+          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md45", null ]
         ] ]
       ] ],
-      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md47", null ],
-      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md48", null ],
-      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md49", null ],
-      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md50", null ],
-      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md51", null ],
-      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md52", null ],
-      [ "Hlms porting", "_ogre22_changes.html#autotoc_md53", null ],
-      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md54", null ]
+      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md46", null ],
+      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md47", null ],
+      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md48", null ],
+      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md49", null ],
+      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md50", null ],
+      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md51", null ],
+      [ "Hlms porting", "_ogre22_changes.html#autotoc_md52", null ],
+      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md53", null ]
     ] ],
-    [ "Behavor of StagingTexture in D3D11", "_behavor_staging_texture_d3_d11.html", [
-      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ],
-      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md19", null ],
-      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md20", null ]
+    [ "Behavior of StagingTexture in D3D11", "_behavior_staging_texture_d3_d11.html", [
+      [ "Attempting to be contiguous", "_behavior_staging_texture_d3_d11.html#autotoc_md16", null ],
+      [ "Slicing in 3", "_behavior_staging_texture_d3_d11.html#autotoc_md17", null ],
+      [ "Slicing in the middle", "_behavior_staging_texture_d3_d11.html#autotoc_md18", null ]
     ] ],
     [ "What's new in Ogre 2.3", "_ogre23_changes.html", [
-      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md55", null ],
-      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md56", null ],
-      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md57", null ],
-      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md58", null ],
-      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md59", null ],
-      [ "PluginOptional", "_ogre23_changes.html#autotoc_md60", null ],
-      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md61", [
-        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md62", null ],
-        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md63", null ]
+      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md54", null ],
+      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md55", null ],
+      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md56", null ],
+      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md57", null ],
+      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md58", null ],
+      [ "PluginOptional", "_ogre23_changes.html#autotoc_md59", null ],
+      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md60", [
+        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md61", null ],
+        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md62", null ]
       ] ]
     ] ],
     [ "Root Layouts", "_root_layouts.html", [
       [ "Old APIs (i.e. D3D11 and GL)", "_root_layouts.html#RootLayoutsOldAPIs", null ],
       [ "New APIs and Root Layouts", "_root_layouts.html#RootLayoutsNewAPIs", null ],
       [ "Setting up root layouts", "_root_layouts.html#RootLayoutsSettingUp", [
-        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md64", null ]
+        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md83", null ]
       ] ],
       [ "Declaring Root Layouts in shaders", "_root_layouts.html#RootLayoutsDeclaringInShaders", null ],
       [ "Baked sets", "_root_layouts.html#RootLayoutsBakedSets", null ],
@@ -355,10 +295,41 @@ var manual =
         [ "Automatic", "_root_layouts.html#RootLayoutsAoTAuto", null ],
         [ "Making GLSL shaders compatible with both Vulkan and OpenGL", "_root_layouts.html#RootLayoutsGLSLForGLandVK", [
           [ "Example:", "_root_layouts.html#RootLayoutsGLSLForGLandVKExample", [
-            [ "OpenGL", "_root_layouts.html#autotoc_md65", null ],
-            [ "Vulkan", "_root_layouts.html#autotoc_md66", null ]
+            [ "OpenGL", "_root_layouts.html#autotoc_md84", null ],
+            [ "Vulkan", "_root_layouts.html#autotoc_md85", null ]
           ] ]
         ] ]
       ] ]
+    ] ],
+    [ "Resolving Merge Conflicts in Ogre-Next 3.0", "_resolving_merge_conflicts30.html", [
+      [ "Notes:", "_resolving_merge_conflicts30.html#autotoc_md81", null ],
+      [ "Batch Script", "_resolving_merge_conflicts30.html#autotoc_md82", null ]
+    ] ],
+    [ "What's new in Ogre-Next 3.0", "_ogre30_changes.html", [
+      [ "Ogre to OgreNext name migration", "_ogre30_changes.html#autotoc_md63", null ],
+      [ "PBS Changes in 3.0", "_ogre30_changes.html#autotoc_md64", null ],
+      [ "Hlms Shader piece changes", "_ogre30_changes.html#autotoc_md65", null ],
+      [ "AbiCookie", "_ogre30_changes.html#autotoc_md66", null ],
+      [ "Move to C++11 and general cleanup", "_ogre30_changes.html#autotoc_md67", null ]
+    ] ],
+    [ "PBR / PBS Changes in 3.0", "_p_b_s_changes_in30.html", [
+      [ "Short version", "_p_b_s_changes_in30.html#autotoc_md68", null ],
+      [ "Long version", "_p_b_s_changes_in30.html#autotoc_md69", [
+        [ "Direct Lighting", "_p_b_s_changes_in30.html#autotoc_md70", [
+          [ "Fresnel Diffuse is no longer considered", "_p_b_s_changes_in30.html#autotoc_md71", [
+            [ "Raffaele's comments:", "_p_b_s_changes_in30.html#autotoc_md72", null ],
+            [ "Default-enable to diffuse fresnel", "_p_b_s_changes_in30.html#autotoc_md73", null ]
+          ] ],
+          [ "Geometric Term change", "_p_b_s_changes_in30.html#autotoc_md74", null ],
+          [ "Metalness change", "_p_b_s_changes_in30.html#autotoc_md75", null ]
+        ] ],
+        [ "IBL", "_p_b_s_changes_in30.html#autotoc_md76", [
+          [ "IBL Diffuse", "_p_b_s_changes_in30.html#autotoc_md77", [
+            [ "Multiplication by PI", "_p_b_s_changes_in30.html#autotoc_md78", null ]
+          ] ],
+          [ "IBL Specular", "_p_b_s_changes_in30.html#autotoc_md79", null ]
+        ] ]
+      ] ],
+      [ "Hemisphere Ambient Lighting changes", "_p_b_s_changes_in30.html#autotoc_md80", null ]
     ] ]
 ];
\ No newline at end of file
