@@ -7,6 +7,5 @@ var searchData=
   ['meshversion_4',['MeshVersion',['../namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7',1,'Ogre::MeshVersion'],['../namespace_ogre_1_1v1.html#ada7f44b0e95a262656a6b5b715c05377',1,'Ogre::v1::MeshVersion']]],
   ['mipmapgenerationmethods_5',['MipmapGenerationMethods',['../class_ogre_1_1_compositor_pass_mipmap_def.html#aa9fc749c877ef112faac9fd759d65eb4',1,'Ogre::CompositorPassMipmapDef']]],
   ['modes_6',['Modes',['../class_ogre_1_1_render_queue.html#ad2b57c9b40e33d4b64f613a5a6147367',1,'Ogre::RenderQueue']]],
-  ['msaapatterns_7',['MsaaPatterns',['../namespace_ogre_1_1_msaa_patterns.html#a54095ce17b1cbaa8972173d9ea950f0f',1,'Ogre::MsaaPatterns']]],
-  ['multiheadusetype_8',['MultiheadUseType',['../class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652f',1,'Ogre::D3D9RenderSystem']]]
+  ['msaapatterns_7',['MsaaPatterns',['../namespace_ogre_1_1_msaa_patterns.html#a54095ce17b1cbaa8972173d9ea950f0f',1,'Ogre::MsaaPatterns']]]
 ];
